@@ -2,11 +2,11 @@
  * \file kml_printer.h
  * \brief Interface of a class that prints PVT information to a kml file
  * \author Javier Arribas, 2011. jarribas(at)cttc.es
- *
+ *         Álvaro Cebrián Juan, 2018. acebrianjuan(at)gmail.com
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -24,7 +24,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -33,11 +33,12 @@
 #ifndef GNSS_SDR_KML_PRINTER_H_
 #define GNSS_SDR_KML_PRINTER_H_
 
-#include <iostream>
+#include "pvt_solution.h"
+#include "rtklib_solver.h"
 #include <fstream>
 #include <memory>
 #include <string>
-#include "pvt_solution.h"
+
 
 /*!
  * \brief Prints PVT information to OGC KML format file (can be viewed with Google Earth)
@@ -48,13 +49,19 @@ class Kml_Printer
 {
 private:
     std::ofstream kml_file;
+    std::ofstream tmp_file;
     bool positions_printed;
     std::string kml_filename;
+    std::string kml_base_path;
+    std::string tmp_file_str;
+    unsigned int point_id;
+    std::string indent;
+
 public:
-    Kml_Printer();
+    Kml_Printer(const std::string& base_path = std::string("."));
     ~Kml_Printer();
-    bool set_headers(std::string filename, bool time_tag_name = true);
-    bool print_position(const std::shared_ptr<Pvt_Solution>& position, bool print_average_values);
+    bool set_headers(const std::string& filename, bool time_tag_name = true);
+    bool print_position(const std::shared_ptr<rtklib_solver>& position, bool print_average_values);
     bool close_file();
 };
 
