@@ -10,7 +10,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -28,7 +28,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -36,11 +36,9 @@
 #ifndef GNSS_SDR_NMEA_PRINTER_H_
 #define GNSS_SDR_NMEA_PRINTER_H_
 
-
-#include <iostream>
+#include "rtklib_solver.h"
 #include <fstream>
 #include <string>
-#include "pvt_solution.h"
 
 
 /*!
@@ -55,12 +53,12 @@ public:
     /*!
      * \brief Default constructor.
      */
-    Nmea_Printer(std::string filename, bool flag_nmea_tty_port, std::string nmea_dump_filename);
+    Nmea_Printer(const std::string& filename, bool flag_nmea_output_file, bool flag_nmea_tty_port, std::string nmea_dump_devname, const std::string& base_path = ".");
 
     /*!
      * \brief Print NMEA PVT and satellite info to the initialized device
      */
-    bool Print_Nmea_Line(const std::shared_ptr<Pvt_Solution>& position, bool print_average_values);
+    bool Print_Nmea_Line(const std::shared_ptr<rtklib_solver>& pvt_data, bool print_average_values);
 
     /*!
      * \brief Default destructor.
@@ -68,22 +66,24 @@ public:
     ~Nmea_Printer();
 
 private:
-    std::string nmea_filename; // String with the NMEA log filename
-    std::ofstream nmea_file_descriptor; // Output file stream for NMEA log file
+    std::string nmea_filename;  // String with the NMEA log filename
+    std::string nmea_base_path;
+    std::ofstream nmea_file_descriptor;  // Output file stream for NMEA log file
     std::string nmea_devname;
-    int nmea_dev_descriptor; // NMEA serial device descriptor (i.e. COM port)
-    std::shared_ptr<Pvt_Solution> d_PVT_data;
-    int init_serial(std::string serial_device); //serial port control
+    int nmea_dev_descriptor;  // NMEA serial device descriptor (i.e. COM port)
+    std::shared_ptr<rtklib_solver> d_PVT_data;
+    int init_serial(const std::string& serial_device);  //serial port control
     void close_serial();
-    std::string get_GPGGA(); // fix data
-    std::string get_GPGSV(); // satellite data
-    std::string get_GPGSA(); // overall satellite reception data
-    std::string get_GPRMC(); // minimum recommended data
+    std::string get_GPGGA();  // fix data
+    std::string get_GPGSV();  // satellite data
+    std::string get_GPGSA();  // overall satellite reception data
+    std::string get_GPRMC();  // minimum recommended data
     std::string get_UTC_NMEA_time(boost::posix_time::ptime d_position_UTC_time);
     std::string longitude_to_hm(double longitude);
     std::string latitude_to_hm(double lat);
     char checkSum(std::string sentence);
     bool print_avg_pos;
+    bool d_flag_nmea_output_file;
 };
 
 #endif
