@@ -25,7 +25,7 @@
  * \author Carles Fernandez Prades, 2011. cfernandez(at)cttc.es
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -43,7 +43,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -51,20 +51,21 @@
 #ifndef GNSS_SDR_RINEX_PRINTER_H_
 #define GNSS_SDR_RINEX_PRINTER_H_
 
-#include <string>
-#include <fstream>
-#include <iostream>
-#include <sstream>  // for stringstream
-#include <iomanip>  // for setprecision
-#include <map>
-#include <boost/date_time/posix_time/posix_time.hpp>
-#include "gps_navigation_message.h"
-#include "gps_cnav_navigation_message.h"
-#include "galileo_navigation_message.h"
-#include "sbas_telemetry_data.h"
+#include "GLONASS_L1_L2_CA.h"
 #include "GPS_L1_CA.h"
 #include "Galileo_E1.h"
+#include "galileo_navigation_message.h"
+#include "glonass_gnav_navigation_message.h"
 #include "gnss_synchro.h"
+#include "gps_cnav_navigation_message.h"
+#include "gps_navigation_message.h"
+#include <boost/date_time/posix_time/posix_time.hpp>
+#include <cstdint>
+#include <fstream>
+#include <iomanip>  // for setprecision
+#include <map>
+#include <sstream>  // for stringstream
+#include <string>
 
 class Sbas_Raw_Msg;
 
@@ -76,174 +77,314 @@ class Rinex_Printer
 {
 public:
     /*!
-     * \brief Default constructor. Creates GPS Navigation and Observables RINEX files and their headers
+     * \brief Default constructor. Creates GNSS Navigation and Observables RINEX files and their headers
      */
-    Rinex_Printer(int version = 0);
+    Rinex_Printer(int version = 0, const std::string& base_path = ".");
 
     /*!
-     * \brief Default destructor. Closes GPS Navigation and Observables RINEX files
+     * \brief Default destructor. Closes GNSS Navigation and Observables RINEX files
      */
     ~Rinex_Printer();
 
-    std::fstream obsFile ; //<! Output file stream for RINEX observation file
-    std::fstream navFile ; //<! Output file stream for RINEX navigation data file
-    std::fstream sbsFile ; //<! Output file stream for RINEX SBAS raw data file
-    std::fstream navGalFile ; //<! Output file stream for RINEX Galileo navigation data file
-    std::fstream navMixFile ; //<! Output file stream for RINEX Mixed navigation data file
+    std::fstream obsFile;     //<! Output file stream for RINEX observation file
+    std::fstream navFile;     //<! Output file stream for RINEX navigation data file
+    std::fstream sbsFile;     //<! Output file stream for RINEX SBAS raw data file
+    std::fstream navGalFile;  //<! Output file stream for RINEX Galileo navigation data file
+    std::fstream navGloFile;  //<! Output file stream for RINEX GLONASS navigation data file
+    std::fstream navMixFile;  //<! Output file stream for RINEX Mixed navigation data file
 
     /*!
      *  \brief Generates the GPS L1 C/A Navigation Data header
      */
-    void rinex_nav_header(std::fstream & out, const Gps_Iono & iono, const Gps_Utc_Model & utc_model);
+    void rinex_nav_header(std::fstream& out, const Gps_Iono& iono, const Gps_Utc_Model& utc_model);
 
     /*!
      *  \brief Generates the GPS L2C(M) Navigation Data header
      */
-    void rinex_nav_header(std::fstream & out, const Gps_CNAV_Iono & iono, const Gps_CNAV_Utc_Model & utc_model);
+    void rinex_nav_header(std::fstream& out, const Gps_CNAV_Iono& iono, const Gps_CNAV_Utc_Model& utc_model);
 
     /*!
      *  \brief Generates the Galileo Navigation Data header
      */
-    void rinex_nav_header(std::fstream & out, const Galileo_Iono & iono, const Galileo_Utc_Model & utc_model, const Galileo_Almanac & galileo_almanac);
+    void rinex_nav_header(std::fstream& out, const Galileo_Iono& iono, const Galileo_Utc_Model& utc_model);
 
     /*!
      *  \brief Generates the Mixed (GPS/Galileo) Navigation Data header
      */
-    void rinex_nav_header(std::fstream & out, const Gps_Iono & gps_iono, const Gps_Utc_Model & gps_utc_model, const Galileo_Iono & galileo_iono, const Galileo_Utc_Model & galileo_utc_model, const Galileo_Almanac & galileo_almanac);
+    void rinex_nav_header(std::fstream& out, const Gps_Iono& gps_iono, const Gps_Utc_Model& gps_utc_model, const Galileo_Iono& galileo_iono, const Galileo_Utc_Model& galileo_utc_model);
+
+    /*!
+     *  \brief Generates the Mixed (GPS CNAV/Galileo) Navigation Data header
+     */
+    void rinex_nav_header(std::fstream& out, const Gps_CNAV_Iono& iono, const Gps_CNAV_Utc_Model& utc_model, const Galileo_Iono& galileo_iono, const Galileo_Utc_Model& galileo_utc_model);
+
+    /*!
+     *  \brief Generates the GLONASS L1, L2 C/A Navigation Data header
+     */
+    void rinex_nav_header(std::fstream& out, const Glonass_Gnav_Utc_Model& utc_model, const Glonass_Gnav_Ephemeris& glonass_gnav_eph);
+
+    /*!
+     *  \brief Generates the Mixed (Galileo/GLONASS) Navigation Data header
+     */
+    void rinex_nav_header(std::fstream& out, const Galileo_Iono& galileo_iono, const Galileo_Utc_Model& galileo_utc_model, const Glonass_Gnav_Utc_Model& glonass_gnav_utc_model, const Glonass_Gnav_Almanac& glonass_gnav_almanac);
+
+    /*!
+     *  \brief Generates the Mixed (GPS L1 C/A/GLONASS L1, L2) Navigation Data header
+     */
+    void rinex_nav_header(std::fstream& out, const Gps_Iono& gps_iono, const Gps_Utc_Model& gps_utc_model, const Glonass_Gnav_Utc_Model& glonass_gnav_utc_model, const Glonass_Gnav_Almanac& glonass_gnav_almanac);
+
+    /*!
+     *  \brief Generates the Mixed (GPS L2C C/A/GLONASS L1, L2) Navigation Data header
+     */
+    void rinex_nav_header(std::fstream& out, const Gps_CNAV_Iono& gps_iono, const Gps_CNAV_Utc_Model& gps_utc_model, const Glonass_Gnav_Utc_Model& glonass_gnav_utc_model, const Glonass_Gnav_Almanac& glonass_gnav_almanac);
 
     /*!
      *  \brief Generates the GPS Observation data header
      */
-    void rinex_obs_header(std::fstream & out, const Gps_Ephemeris & eph, const double d_TOW_first_observation);
+    void rinex_obs_header(std::fstream& out, const Gps_Ephemeris& eph, const double d_TOW_first_observation);
 
     /*!
      *  \brief Generates the GPS L2 Observation data header
      */
-    void rinex_obs_header(std::fstream & out, const Gps_CNAV_Ephemeris & eph, const double d_TOW_first_observation);
+    void rinex_obs_header(std::fstream& out, const Gps_CNAV_Ephemeris& eph, const double d_TOW_first_observation, const std::string& gps_bands = "2S");
 
     /*!
-     *  \brief Generates the dual frequency GPS L1 & L2 Observation data header
+     *  \brief Generates the dual frequency GPS L1 & L2/L5 Observation data header
      */
-    void rinex_obs_header(std::fstream & out, const Gps_Ephemeris & eph, const Gps_CNAV_Ephemeris & eph_cnav, const double d_TOW_first_observation);
+    void rinex_obs_header(std::fstream& out, const Gps_Ephemeris& eph, const Gps_CNAV_Ephemeris& eph_cnav, const double d_TOW_first_observation, const std::string& gps_bands = "1C 2S");
 
     /*!
      *  \brief Generates the Galileo Observation data header. Example: bands("1B"), bands("1B 5X"), bands("5X"), ... Default: "1B".
      */
-    void rinex_obs_header(std::fstream & out, const Galileo_Ephemeris & eph, const double d_TOW_first_observation, const std::string bands = "1B");
+    void rinex_obs_header(std::fstream& out, const Galileo_Ephemeris& eph, const double d_TOW_first_observation, const std::string& bands = "1B");
 
     /*!
      *  \brief Generates the Mixed (GPS/Galileo) Observation data header. Example: galileo_bands("1B"), galileo_bands("1B 5X"), galileo_bands("5X"), ... Default: "1B".
      */
-    void rinex_obs_header(std::fstream & out, const Gps_Ephemeris & gps_eph, const Galileo_Ephemeris & galileo_eph, const double d_TOW_first_observation, const std::string galileo_bands = "1B");
+    void rinex_obs_header(std::fstream& out, const Gps_Ephemeris& gps_eph, const Galileo_Ephemeris& galileo_eph, const double d_TOW_first_observation, const std::string& galileo_bands = "1B");
+
+    /*!
+     *  \brief Generates the Mixed (GPS/Galileo) Observation data header. Example: galileo_bands("1B"), galileo_bands("1B 5X"), galileo_bands("5X"), ... Default: "1B".
+     */
+    void rinex_obs_header(std::fstream& out, const Gps_Ephemeris& gps_eph, const Gps_CNAV_Ephemeris& eph_cnav, const Galileo_Ephemeris& galileo_eph, const double d_TOW_first_observation, const std::string& gps_bands = "1C 2S", const std::string& galileo_bands = "1B");
+
+    /*!
+     *  \brief Generates the Mixed (GPS/Galileo) Observation data header. Example: galileo_bands("1B"), galileo_bands("1B 5X"), galileo_bands("5X"), ... Default: "1B".
+     */
+    void rinex_obs_header(std::fstream& out, const Gps_CNAV_Ephemeris& eph_cnav, const Galileo_Ephemeris& galileo_eph, const double d_TOW_first_observation, const std::string& gps_bands = "2S", const std::string& galileo_bands = "1B");
+
+    /*!
+     *  \brief Generates the GLONASS GNAV Observation data header. Example: bands("1C"), bands("1C 2C"), bands("2C"), ... Default: "1C".
+     */
+    void rinex_obs_header(std::fstream& out, const Glonass_Gnav_Ephemeris& eph, const double d_TOW_first_observation, const std::string& bands = "1G");
+
+    /*!
+     *  \brief Generates the Mixed (GPS L1 C/A /GLONASS) Observation data header. Example: galileo_bands("1C"), galileo_bands("1B 5X"), galileo_bands("5X"), ... Default: "1B".
+     */
+    void rinex_obs_header(std::fstream& out, const Gps_Ephemeris& gps_eph, const Glonass_Gnav_Ephemeris& glonass_gnav_eph, const double d_TOW_first_observation, const std::string& glo_bands = "1C");
+
+    /*!
+     *  \brief Generates the Mixed (Galileo/GLONASS) Observation data header. Example: galileo_bands("1C"), galileo_bands("1B 5X"), galileo_bands("5X"), ... Default: "1B".
+     */
+    void rinex_obs_header(std::fstream& out, const Galileo_Ephemeris& galileo_eph, const Glonass_Gnav_Ephemeris& glonass_gnav_eph, const double d_TOW_first_observation, const std::string& galileo_bands = "1B", const std::string& glo_bands = "1C");
+
+    /*!
+     *  \brief Generates the Mixed (GPS L2C/GLONASS) Observation data header. Example: galileo_bands("1G")... Default: "1G".
+     */
+    void rinex_obs_header(std::fstream& out, const Gps_CNAV_Ephemeris& gps_cnav_eph, const Glonass_Gnav_Ephemeris& glonass_gnav_eph, const double d_TOW_first_observation, const std::string& glo_bands = "1G");
 
     /*!
      *  \brief Generates the SBAS raw data header
      */
-    void rinex_sbs_header(std::fstream & out);
+    void rinex_sbs_header(std::fstream& out);
 
     /*!
      *  \brief Computes the UTC time and returns a boost::posix_time::ptime object
      */
-    boost::posix_time::ptime compute_UTC_time(const Gps_Navigation_Message & nav_msg);
+    boost::posix_time::ptime compute_UTC_time(const Gps_Navigation_Message& nav_msg);
 
     /*!
      *  \brief Computes the GPS time and returns a boost::posix_time::ptime object
      */
-    boost::posix_time::ptime compute_GPS_time(const Gps_Ephemeris & eph, const double obs_time);
+    boost::posix_time::ptime compute_GPS_time(const Gps_Ephemeris& eph, const double obs_time);
 
     /*!
      *  \brief Computes the GPS time and returns a boost::posix_time::ptime object
      */
-    boost::posix_time::ptime compute_GPS_time(const Gps_CNAV_Ephemeris & eph, const double obs_time);
+    boost::posix_time::ptime compute_GPS_time(const Gps_CNAV_Ephemeris& eph, const double obs_time);
 
     /*!
      *  \brief Computes the Galileo time and returns a boost::posix_time::ptime object
      */
-    boost::posix_time::ptime compute_Galileo_time(const Galileo_Ephemeris & eph, const double obs_time);
+    boost::posix_time::ptime compute_Galileo_time(const Galileo_Ephemeris& eph, const double obs_time);
+
+    /*!
+     *  \brief Computes the UTC Time and returns a boost::posix_time::ptime object
+     *  \details Function used as a method to convert the observation time into UTC time which is used
+     *  as the default time for RINEX files
+     *  \param eph GLONASS GNAV Ephemeris object
+     *  \param obs_time Observation time in GPS seconds of week
+     */
+    boost::posix_time::ptime compute_UTC_time(const Glonass_Gnav_Ephemeris& eph, const double obs_time);
+
+    /*!
+     *  \brief Computes number of leap seconds of GPS relative to UTC
+     *  \param eph GLONASS GNAV Ephemeris object
+     *  \param gps_obs_time Observation time in GPS seconds of week
+     */
+    double get_leap_second(const Glonass_Gnav_Ephemeris& eph, const double gps_obs_time);
 
     /*!
      *  \brief Writes data from the GPS L1 C/A navigation message into the RINEX file
      */
-    void log_rinex_nav(std::fstream & out, const std::map<int, Gps_Ephemeris> & eph_map);
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Gps_Ephemeris>& eph_map);
 
     /*!
      *  \brief Writes data from the GPS L2 navigation message into the RINEX file
      */
-    void log_rinex_nav(std::fstream & out, const std::map<int, Gps_CNAV_Ephemeris> & eph_map);
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Gps_CNAV_Ephemeris>& eph_map);
 
     /*!
      *  \brief Writes data from the Galileo navigation message into the RINEX file
      */
-    void log_rinex_nav(std::fstream & out, const std::map<int, Galileo_Ephemeris> & eph_map);
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Galileo_Ephemeris>& eph_map);
 
     /*!
      *  \brief Writes data from the Mixed (GPS/Galileo) navigation message into the RINEX file
      */
-    void log_rinex_nav(std::fstream & out, const std::map<int, Gps_Ephemeris> & gps_eph_map, const std::map<int, Galileo_Ephemeris> & galileo_eph_map);
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Gps_Ephemeris>& gps_eph_map, const std::map<int32_t, Galileo_Ephemeris>& galileo_eph_map);
+
+    /*!
+     *  \brief Writes data from the Mixed (GPS/Galileo) navigation message into the RINEX file
+     */
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Gps_CNAV_Ephemeris>& gps_cnav_eph_map, const std::map<int32_t, Galileo_Ephemeris>& galileo_eph_map);
+
+    /*!
+     *  \brief Writes data from the GLONASS GNAV navigation message into the RINEX file
+     */
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Glonass_Gnav_Ephemeris>& eph_map);
+
+    /*!
+     *  \brief Writes data from the Mixed (GPS/GLONASS GNAV) navigation message into the RINEX file
+     */
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Gps_Ephemeris>& gps_eph_map, const std::map<int32_t, Glonass_Gnav_Ephemeris>& glonass_gnav_eph_map);
+
+    /*!
+     *  \brief Writes data from the Mixed (GPS/GLONASS GNAV) navigation message into the RINEX file
+     */
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Gps_CNAV_Ephemeris>& gps_cnav_eph_map, const std::map<int32_t, Glonass_Gnav_Ephemeris>& glonass_gnav_eph_map);
+
+    /*!
+     *  \brief Writes data from the Mixed (Galileo/ GLONASS GNAV) navigation message into the RINEX file
+     */
+    void log_rinex_nav(std::fstream& out, const std::map<int32_t, Galileo_Ephemeris>& galileo_eph_map, const std::map<int32_t, Glonass_Gnav_Ephemeris>& glonass_gnav_eph_map);
 
     /*!
      *  \brief Writes GPS L1 observables into the RINEX file
      */
-    void log_rinex_obs(std::fstream & out, const Gps_Ephemeris & eph, double obs_time, const std::map<int, Gnss_Synchro> & observables);
+    void log_rinex_obs(std::fstream& out, const Gps_Ephemeris& eph, double obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
 
     /*!
      *  \brief Writes GPS L2 observables into the RINEX file
      */
-    void log_rinex_obs(std::fstream & out, const Gps_CNAV_Ephemeris & eph, double obs_time, const std::map<int, Gnss_Synchro> & observables);
+    void log_rinex_obs(std::fstream& out, const Gps_CNAV_Ephemeris& eph, double obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
 
     /*!
      *  \brief Writes dual frequency GPS L1 and L2 observables into the RINEX file
      */
-    void log_rinex_obs(std::fstream & out, const Gps_Ephemeris & eph, const Gps_CNAV_Ephemeris & eph_cnav, double obs_time, const std::map<int, Gnss_Synchro> & observables);
+    void log_rinex_obs(std::fstream& out, const Gps_Ephemeris& eph, const Gps_CNAV_Ephemeris& eph_cnav, double obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
 
     /*!
      *  \brief Writes Galileo observables into the RINEX file. Example: galileo_bands("1B"), galileo_bands("1B 5X"), galileo_bands("5X"), ... Default: "1B".
      */
-    void log_rinex_obs(std::fstream & out, const Galileo_Ephemeris & eph, double obs_time, const std::map<int, Gnss_Synchro> & observables, const std::string galileo_bands = "1B");
+    void log_rinex_obs(std::fstream& out, const Galileo_Ephemeris& eph, double obs_time, const std::map<int32_t, Gnss_Synchro>& observables, const std::string& galileo_bands = "1B");
 
     /*!
      *  \brief Writes Mixed GPS / Galileo observables into the RINEX file
      */
-    void log_rinex_obs(std::fstream & out, const Gps_Ephemeris & gps_eph, const Galileo_Ephemeris & galileo_eph, const double gps_obs_time, const std::map<int, Gnss_Synchro> & observables);
+    void log_rinex_obs(std::fstream& out, const Gps_Ephemeris& gps_eph, const Galileo_Ephemeris& galileo_eph, const double gps_obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
+
+    /*!
+     *  \brief Writes Mixed GPS / Galileo observables into the RINEX file
+     */
+    void log_rinex_obs(std::fstream& out, const Gps_CNAV_Ephemeris& eph, const Galileo_Ephemeris& galileo_eph, double gps_obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
+
+    /*!
+     *  \brief Writes Mixed GPS / Galileo observables into the RINEX file
+     */
+    void log_rinex_obs(std::fstream& out, const Gps_Ephemeris& gps_eph, const Gps_CNAV_Ephemeris& gps_cnav_eph, const Galileo_Ephemeris& galileo_eph, double gps_obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
+
+    /*!
+     *  \brief Writes GLONASS GNAV observables into the RINEX file. Example: glonass_bands("1C"), galileo_bands("1B 5X"), galileo_bands("5X"), ... Default: "1B".
+     */
+    void log_rinex_obs(std::fstream& out, const Glonass_Gnav_Ephemeris& eph, double obs_time, const std::map<int32_t, Gnss_Synchro>& observables, const std::string& glonass_bands = "1C");
+
+    /*!
+     *  \brief Writes Mixed GPS L1 C/A - GLONASS observables into the RINEX file
+     */
+    void log_rinex_obs(std::fstream& out, const Gps_Ephemeris& gps_eph, const Glonass_Gnav_Ephemeris& glonass_gnav_eph, const double gps_obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
+
+    /*!
+     *  \brief Writes Mixed GPS L2C - GLONASS observables into the RINEX file
+     */
+    void log_rinex_obs(std::fstream& out, const Gps_CNAV_Ephemeris& gps_cnav_eph, const Glonass_Gnav_Ephemeris& glonass_gnav_eph, const double gps_obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
+
+    /*!
+     *  \brief Writes Mixed Galileo/GLONASS observables into the RINEX file
+     */
+    void log_rinex_obs(std::fstream& out, const Galileo_Ephemeris& galileo_eph, const Glonass_Gnav_Ephemeris& glonass_gnav_eph, const double gps_obs_time, const std::map<int32_t, Gnss_Synchro>& observables);
 
     /*!
      * \brief Represents GPS time in the date time format. Leap years are considered, but leap seconds are not.
      */
-    void to_date_time(int gps_week, int gps_tow, int & year, int & month, int & day, int & hour, int & minute, int & second);
+    void to_date_time(int gps_week, int gps_tow, int& year, int& month, int& day, int& hour, int& minute, int& second);
 
     /*!
      *  \brief Writes raw SBAS messages into the RINEX file
      */
-    void log_rinex_sbs(std::fstream & out, const Sbas_Raw_Msg & sbs_message);
+    //void log_rinex_sbs(std::fstream & out, const Sbas_Raw_Msg & sbs_message);
 
-    void update_nav_header(std::fstream & out, const Gps_Utc_Model & gps_utc, const Gps_Iono & gps_iono);
+    void update_nav_header(std::fstream& out, const Gps_Utc_Model& gps_utc, const Gps_Iono& gps_iono);
 
-    void update_nav_header(std::fstream & out, const Gps_CNAV_Utc_Model & utc_model, const Gps_CNAV_Iono & iono);
+    void update_nav_header(std::fstream& out, const Gps_CNAV_Utc_Model& utc_model, const Gps_CNAV_Iono& iono);
 
-    void update_nav_header(std::fstream & out, const Gps_Iono & gps_iono, const Gps_Utc_Model & gps_utc_model, const Galileo_Iono & galileo_iono, const Galileo_Utc_Model & galileo_utc_model, const Galileo_Almanac& galileo_almanac);
+    void update_nav_header(std::fstream& out, const Gps_Iono& gps_iono, const Gps_Utc_Model& gps_utc_model, const Galileo_Iono& galileo_iono, const Galileo_Utc_Model& galileo_utc_model);
 
-    void update_nav_header(std::fstream & out, const Galileo_Iono & galileo_iono, const Galileo_Utc_Model & utc_model, const Galileo_Almanac & galileo_almanac);
+    void update_nav_header(std::fstream& out, const Gps_CNAV_Utc_Model& utc_model, const Gps_CNAV_Iono& iono, const Galileo_Iono& galileo_iono, const Galileo_Utc_Model& galileo_utc_model);
 
-    void update_obs_header(std::fstream & out, const Gps_Utc_Model & utc_model);
+    void update_nav_header(std::fstream& out, const Galileo_Iono& galileo_iono, const Galileo_Utc_Model& utc_model);
 
-    void update_obs_header(std::fstream & out, const Gps_CNAV_Utc_Model & utc_model);
+    void update_nav_header(std::fstream& out, const Glonass_Gnav_Utc_Model& glonass_gnav_utc_model, const Glonass_Gnav_Almanac& glonass_gnav_almanac);
 
-    void update_obs_header(std::fstream & out, const Galileo_Utc_Model & galileo_utc_model);
+    void update_nav_header(std::fstream& out, const Gps_Iono& gps_iono, const Gps_Utc_Model& gps_utc, const Glonass_Gnav_Utc_Model& glonass_gnav_utc_model, const Glonass_Gnav_Almanac& glonass_gnav_almanac);
 
-    std::map<std::string,std::string> satelliteSystem; //<! GPS, GLONASS, SBAS payload, Galileo or Compass
-    std::map<std::string,std::string> observationType; //<! PSEUDORANGE, CARRIER_PHASE, DOPPLER, SIGNAL_STRENGTH
-    std::map<std::string,std::string> observationCode; //<! GNSS observation descriptors
-    std::string stringVersion; //<! RINEX version (2.10/2.11 or 3.01/3.02)
+    void update_nav_header(std::fstream& out, const Gps_CNAV_Iono& gps_cnav_iono, const Gps_CNAV_Utc_Model& gps_cnav_utc, const Glonass_Gnav_Utc_Model& glonass_gnav_utc_model, const Glonass_Gnav_Almanac& glonass_gnav_almanac);
+
+    void update_nav_header(std::fstream& out, const Galileo_Iono& galileo_iono, const Galileo_Utc_Model& galileo_utc_model, const Glonass_Gnav_Utc_Model& glonass_gnav_utc_model, const Glonass_Gnav_Almanac& glonass_gnav_almanac);
+
+    void update_obs_header(std::fstream& out, const Gps_Utc_Model& utc_model);
+
+    void update_obs_header(std::fstream& out, const Gps_CNAV_Utc_Model& utc_model);
+
+    void update_obs_header(std::fstream& out, const Galileo_Utc_Model& galileo_utc_model);
+
+    void update_obs_header(std::fstream& out, const Glonass_Gnav_Utc_Model& glonass_gnav_utc_model);
+
+    std::map<std::string, std::string> satelliteSystem;  //<! GPS, GLONASS, SBAS payload, Galileo or Compass
+    std::map<std::string, std::string> observationType;  //<! PSEUDORANGE, CARRIER_PHASE, DOPPLER, SIGNAL_STRENGTH
+    std::map<std::string, std::string> observationCode;  //<! GNSS observation descriptors
+    std::string stringVersion;                           //<! RINEX version (2.10/2.11 or 3.01/3.02)
 
     std::string navfilename;
     std::string obsfilename;
     std::string sbsfilename;
     std::string navGalfilename;
+    std::string navGlofilename;
     std::string navMixfilename;
 
 private:
-    int version ;  // RINEX version (2 for 2.10/2.11 and 3 for 3.01)
-    int numberTypesObservations; // Number of available types of observable in the system. Should be public?
+    int version;                  // RINEX version (2 for 2.10/2.11 and 3 for 3.01)
+    int numberTypesObservations;  // Number of available types of observable in the system. Should be public?
     /*
      * Generation of RINEX signal strength indicators
      */
@@ -265,7 +406,7 @@ private:
      * "RINEX_FILE_TYPE_SBAS" - SBAS broadcast data file.
      * "RINEX_FILE_TYPE_CLK" - Clock file.
      */
-    std::string createFilename(std::string type);
+    std::string createFilename(const std::string& type);
 
     /*
      * Generates the data for the PGM / RUN BY / DATE line
@@ -275,7 +416,9 @@ private:
     /*
      *  Checks that the line is 80 characters length
      */
-    void lengthCheck(const std::string & line);
+    void lengthCheck(const std::string& line);
+
+    double fake_cnav_iode;
 
     /*
      * If the string is bigger than length, truncate it from the right.
@@ -290,9 +433,9 @@ private:
      * \param[in] length new desired length of string.
      * \param[in] pad character to pad string with (blank by default).
      * \return a reference to \a s.  */
-    inline std::string & leftJustify(std::string & s,
-            const std::string::size_type length,
-            const char pad = ' ');
+    inline std::string& leftJustify(std::string& s,
+        const std::string::size_type length,
+        const char pad = ' ');
 
     /*
      * If the string is bigger than length, truncate it from the right.
@@ -307,11 +450,12 @@ private:
      * \param[in] length new desired length of string.
      * \param[in] pad character to pad string with (blank by default).
      * \return a reference to \a s.  */
-    inline std::string leftJustify(const std::string & s,
-            const std::string::size_type length,
-            const char pad = ' ')
+    inline std::string leftJustify(const std::string& s,
+        const std::string::size_type length,
+        const char pad = ' ')
     {
-        std::string t(s); return leftJustify(t, length, pad);
+        std::string t(s);
+        return leftJustify(t, length, pad);
     }
 
 
@@ -321,9 +465,9 @@ private:
      * requested length (\a length), it is padded on the left with
      * the pad character (\a pad). The default pad
      * character is a blank. */
-    inline std::string & rightJustify(std::string & s,
-            const std::string::size_type length,
-            const char pad = ' ');
+    inline std::string& rightJustify(std::string& s,
+        const std::string::size_type length,
+        const char pad = ' ');
 
     /*
      * Right-justifies the receiver in a string of the specified
@@ -331,11 +475,12 @@ private:
      * requested length (\a length), it is padded on the left with
      * the pad character (\a pad). The default pad
      * character is a blank.*/
-    inline std::string rightJustify(const std::string & s,
-            const std::string::size_type length,
-            const char pad = ' ')
+    inline std::string rightJustify(const std::string& s,
+        const std::string::size_type length,
+        const char pad = ' ')
     {
-        std::string t(s); return rightJustify(t, length, pad);
+        std::string t(s);
+        return rightJustify(t, length, pad);
     }
 
 
@@ -349,11 +494,11 @@ private:
      * exponentials above three characters in length.  If false, it removes
      * that check.
      */
-    inline std::string doub2sci(const double & d,
-            const std::string::size_type length,
-            const std::string::size_type expLen,
-            const bool showSign = true,
-            const bool checkSwitch = true);
+    inline std::string doub2sci(const double& d,
+        const std::string::size_type length,
+        const std::string::size_type expLen,
+        const bool showSign = true,
+        const bool checkSwitch = true);
 
 
     /*
@@ -370,11 +515,11 @@ private:
      * produce an exponential with an E instead of a D, and always have a leading
      * zero.  For example -> 0.87654E-0004 or -0.1234E00005.
      */
-    inline std::string & sci2for(std::string & aStr,
-            const std::string::size_type startPos = 0,
-            const std::string::size_type length = std::string::npos,
-            const std::string::size_type expLen = 3,
-            const bool checkSwitch = true);
+    inline std::string& sci2for(std::string& aStr,
+        const std::string::size_type startPos = 0,
+        const std::string::size_type length = std::string::npos,
+        const std::string::size_type expLen = 3,
+        const bool checkSwitch = true);
 
 
     /*
@@ -389,10 +534,10 @@ private:
      * that check.
      * @return a string containing \a d in FORTRAN notation.
      */
-    inline std::string doub2for(const double & d,
-            const std::string::size_type length,
-            const std::string::size_type expLen,
-            const bool checkSwitch = true);
+    inline std::string doub2for(const double& d,
+        const std::string::size_type length,
+        const std::string::size_type expLen,
+        const bool checkSwitch = true);
 
 
     /*
@@ -400,9 +545,9 @@ private:
      * @param s string containing a number.
      * @return double representation of string.
      */
-    inline double asDouble(const std::string & s)
+    inline double asDouble(const std::string& s)
     {
-        return strtod(s.c_str(), 0);
+        return strtod(s.c_str(), nullptr);
     }
 
 
@@ -411,11 +556,11 @@ private:
     /*
      * Convert a string to an integer.
      * @param s string containing a number.
-     * @return long integer representation of string.
+     * @return int64_t  integer representation of string.
      */
-    inline long asInt(const std::string & s)
+    inline int64_t asInt(const std::string& s)
     {
-        return strtol(s.c_str(), 0, 10);
+        return strtol(s.c_str(), nullptr, 10);
     }
 
 
@@ -426,7 +571,7 @@ private:
      * @return string representation of \a x.
      */
     inline std::string asString(const double x,
-            const std::string::size_type precision = 17);
+        const std::string::size_type precision = 17);
 
 
     /*
@@ -436,7 +581,7 @@ private:
      * @return string representation of \a x.
      */
     inline std::string asString(const long double x,
-            const std::string::size_type precision = 21);
+        const std::string::size_type precision = 21);
 
 
     /*
@@ -445,26 +590,26 @@ private:
      * @param x object to turn into a string.
      * @return string representation of \a x.
      */
-    template <class X> inline std::string asString(const X x);
+    template <class X>
+    inline std::string asString(const X x);
 
     inline std::string asFixWidthString(const int x, const int width, char fill_digit);
 };
 
 
-
 // Implementation of inline functions (modified versions from GPSTk http://www.gpstk.org)
 
-inline std::string & Rinex_Printer::leftJustify(std::string & s,
-        const std::string::size_type length,
-        const char pad)
+inline std::string& Rinex_Printer::leftJustify(std::string& s,
+    const std::string::size_type length,
+    const char pad)
 {
-    if(length < s.length())
+    if (length < s.length())
         {
             s = s.substr(0, length);
         }
     else
         {
-            s.append(length-s.length(), pad);
+            s.append(length - s.length(), pad);
         }
     return s;
 }
@@ -472,27 +617,26 @@ inline std::string & Rinex_Printer::leftJustify(std::string & s,
 
 // if the string is bigger than length, truncate it from the left.
 // otherwise, add pad characters to its left.
-inline std::string & Rinex_Printer::rightJustify(std::string & s,
-        const std::string::size_type length,
-        const char pad)
+inline std::string& Rinex_Printer::rightJustify(std::string& s,
+    const std::string::size_type length,
+    const char pad)
 {
-    if(length < s.length())
+    if (length < s.length())
         {
-            s = s.substr(s.length()-length, std::string::npos);
+            s = s.substr(s.length() - length, std::string::npos);
         }
     else
         {
-            s.insert((std::string::size_type)0, length-s.length(), pad);
+            s.insert(static_cast<std::string::size_type>(0), length - s.length(), pad);
         }
     return s;
 }
 
 
-
-inline std::string Rinex_Printer::doub2for(const double & d,
-        const std::string::size_type length,
-        const std::string::size_type expLen,
-        const bool checkSwitch)
+inline std::string Rinex_Printer::doub2for(const double& d,
+    const std::string::size_type length,
+    const std::string::size_type expLen,
+    const bool checkSwitch)
 {
     short exponentLength = expLen;
 
@@ -507,11 +651,11 @@ inline std::string Rinex_Printer::doub2for(const double & d,
 }
 
 
-inline std::string Rinex_Printer::doub2sci(const double & d,
-        const std::string::size_type length,
-        const std::string::size_type expLen,
-        const bool showSign,
-        const bool checkSwitch)
+inline std::string Rinex_Printer::doub2sci(const double& d,
+    const std::string::size_type length,
+    const std::string::size_type expLen,
+    const bool showSign,
+    const bool checkSwitch)
 {
     std::string toReturn;
     short exponentLength = expLen;
@@ -538,19 +682,19 @@ inline std::string Rinex_Printer::doub2sci(const double & d,
 }
 
 
-inline std::string & Rinex_Printer::sci2for(std::string & aStr,
-        const std::string::size_type startPos,
-        const std::string::size_type length,
-        const std::string::size_type expLen,
-        const bool checkSwitch)
+inline std::string& Rinex_Printer::sci2for(std::string& aStr,
+    const std::string::size_type startPos,
+    const std::string::size_type length,
+    const std::string::size_type expLen,
+    const bool checkSwitch)
 {
     std::string::size_type idx = aStr.find('.', startPos);
     int expAdd = 0;
     std::string exp;
-    long iexp;
+    int64_t iexp;
     //If checkSwitch is false, always redo the exponential. Otherwise,
     //set it to false.
-    bool redoexp =! checkSwitch;
+    bool redoexp = !checkSwitch;
 
     // Check for decimal place within specified boundaries
     if ((idx <= 0) || (idx >= (startPos + length - expLen - 1)))
@@ -602,35 +746,34 @@ inline std::string & Rinex_Printer::sci2for(std::string & aStr,
             if (iexp < 0)
                 {
                     aStr += "-";
-                    iexp -= iexp*2;
+                    iexp -= iexp * 2;
                 }
             else
                 aStr += "+";
-            aStr += Rinex_Printer::rightJustify(asString(iexp),expLen,'0');
+            aStr += Rinex_Printer::rightJustify(asString(iexp), expLen, '0');
         }
 
     // if the number is positive, append a space
     // (if it's negative, there's a leading '-'
     if (aStr[0] == '.')
         {
-            aStr.insert((std::string::size_type)0, 1, ' ');
+            aStr.insert(static_cast<std::string::size_type>(0), 1, ' ');
         }
 
     //If checkSwitch is false, add on one leading zero to the string
     if (!checkSwitch)
         {
-            aStr.insert((std::string::size_type)1, 1, '0');
+            aStr.insert(static_cast<std::string::size_type>(1), 1, '0');
         }
 
     return aStr;
 }  // end sci2for
 
 
-
 inline std::string asString(const long double x, const std::string::size_type precision)
 {
     std::ostringstream ss;
-    ss << std::fixed << std::setprecision(precision) << x ;
+    ss << std::fixed << std::setprecision(precision) << x;
     return ss.str();
 }
 
@@ -651,9 +794,9 @@ inline std::string Rinex_Printer::asFixWidthString(const int x, const int width,
 }
 
 
-inline long asInt(const std::string & s)
+inline int64_t asInt(const std::string& s)
 {
-    return strtol(s.c_str(), 0, 10);
+    return strtol(s.c_str(), nullptr, 10);
 }
 
 
@@ -661,16 +804,17 @@ inline int Rinex_Printer::toInt(std::string bitString, int sLength)
 {
     int tempInt;
     int num = 0;
-    for(int i = 0; i < sLength; i++)
-    {
-        tempInt = bitString[i]-'0';
-        num |= (1 << (sLength - 1 - i)) * tempInt;
-    }
+    for (int i = 0; i < sLength; i++)
+        {
+            tempInt = bitString[i] - '0';
+            num |= (1 << (sLength - 1 - i)) * tempInt;
+        }
     return num;
 }
 
 
-template<class X> inline std::string Rinex_Printer::asString(const X x)
+template <class X>
+inline std::string Rinex_Printer::asString(const X x)
 {
     std::ostringstream ss;
     ss << x;
