@@ -1,8 +1,9 @@
 /*!
  * \file pcps_acquisition_fine_doppler_acquisition_cc.h
  * \brief This class implements a Parallel Code Phase Search Acquisition with multi-dwells and fine Doppler estimation
+ * for GPS L1 C/A signal
  *
- *  Acquisition strategy (Kay Borre book + CFAR threshold).
+ *  Acquisition strategy (Kay Borre book).
  *  <ol>
  *  <li> Compute the input signal power estimation
  *  <li> Doppler serial search loop
@@ -14,7 +15,7 @@
  *
  * Kay Borre book: K.Borre, D.M.Akos, N.Bertelsen, P.Rinder, and S.H.Jensen,
  * "A Software-Defined GPS and Galileo Receiver. A Single-Frequency
- * Approach", Birkha user, 2007. pp 81-84
+ * Approach", Birkhauser, 2007. pp 81-84
  *
  * \authors <ul>
  *          <li> Javier Arribas, 2013. jarribas(at)cttc.es
@@ -22,7 +23,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -40,7 +41,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -48,73 +49,59 @@
 #ifndef GNSS_SDR_PCPS_ACQUISITION_FINE_DOPPLER_CC_H_
 #define GNSS_SDR_PCPS_ACQUISITION_FINE_DOPPLER_CC_H_
 
+#include "acq_conf.h"
+#include "gnss_synchro.h"
+#include <armadillo>
+#include <gnuradio/block.h>
+#include <gnuradio/fft/fft.h>
+#include <gnuradio/gr_complex.h>
 #include <fstream>
 #include <string>
-#include <gnuradio/block.h>
-#include <gnuradio/gr_complex.h>
-#include <gnuradio/fft/fft.h>
-#include "gnss_synchro.h"
 
 class pcps_acquisition_fine_doppler_cc;
 
 typedef boost::shared_ptr<pcps_acquisition_fine_doppler_cc>
-pcps_acquisition_fine_doppler_cc_sptr;
+    pcps_acquisition_fine_doppler_cc_sptr;
 
 pcps_acquisition_fine_doppler_cc_sptr
-pcps_make_acquisition_fine_doppler_cc(int max_dwells, unsigned int sampled_ms,
-        int doppler_max, int doppler_min, long freq, long fs_in, int samples_per_ms,
-        bool dump, std::string dump_filename);
+pcps_make_acquisition_fine_doppler_cc(const Acq_Conf& conf_);
 
 /*!
  * \brief This class implements a Parallel Code Phase Search Acquisition.
  *
- * Check \ref Navitec2012 "An Open Source Galileo E1 Software Receiver",
- * Algorithm 1, for a pseudocode description of this implementation.
  */
-
-class pcps_acquisition_fine_doppler_cc: public gr::block
+class pcps_acquisition_fine_doppler_cc : public gr::block
 {
 private:
     friend pcps_acquisition_fine_doppler_cc_sptr
-    pcps_make_acquisition_fine_doppler_cc(int max_dwells, unsigned int sampled_ms,
-            int doppler_max, int doppler_min, long freq, long fs_in,
-            int samples_per_ms, bool dump,
-            std::string dump_filename);
+    pcps_make_acquisition_fine_doppler_cc(const Acq_Conf& conf_);
+    pcps_acquisition_fine_doppler_cc(const Acq_Conf& conf_);
 
-    pcps_acquisition_fine_doppler_cc(int max_dwells, unsigned int sampled_ms,
-            int doppler_max, int doppler_min, long freq, long fs_in,
-            int samples_per_ms, bool dump,
-            std::string dump_filename);
-
-    void calculate_magnitudes(gr_complex* fft_begin, int doppler_shift,
-            int doppler_offset);
-
-    int compute_and_accumulate_grid(gr_vector_const_void_star &input_items);
-    int estimate_Doppler(gr_vector_const_void_star &input_items);
-    float estimate_input_power(gr_vector_const_void_star &input_items);
-    double search_maximum();
+    int compute_and_accumulate_grid(gr_vector_const_void_star& input_items);
+    int estimate_Doppler();
+    float estimate_input_power(gr_vector_const_void_star& input_items);
+    double compute_CAF();
     void reset_grid();
     void update_carrier_wipeoff();
     void free_grid_memory();
+    bool start();
 
+    Acq_Conf acq_parameters;
     long d_fs_in;
-    long d_freq;
     int d_samples_per_ms;
     int d_max_dwells;
-    unsigned int d_doppler_resolution;
     int d_gnuradio_forecast_samples;
     float d_threshold;
     std::string d_satellite_str;
     int d_config_doppler_max;
-    int d_config_doppler_min;
 
     int d_num_doppler_points;
     int d_doppler_step;
-    unsigned int d_sampled_ms;
     unsigned int d_fft_size;
-    unsigned long int d_sample_counter;
+    uint64_t d_sample_counter;
     gr_complex* d_carrier;
     gr_complex* d_fft_codes;
+    gr_complex* d_10_ms_buffer;
     float* d_magnitude;
 
     float** d_grid_data;
@@ -122,20 +109,25 @@ private:
 
     gr::fft::fft_complex* d_fft_if;
     gr::fft::fft_complex* d_ifft;
-    Gnss_Synchro *d_gnss_synchro;
+    Gnss_Synchro* d_gnss_synchro;
     unsigned int d_code_phase;
     float d_doppler_freq;
-    float d_input_power;
     float d_test_statistics;
-    std::ofstream d_dump_file;
+    int d_positive_acq;
+
     int d_state;
     bool d_active;
     int d_well_count;
+    int d_n_samples_in_buffer;
     bool d_dump;
     unsigned int d_channel;
 
     std::string d_dump_filename;
 
+    arma ::fmat grid_;
+    int64_t d_dump_number;
+    unsigned int d_dump_channel;
+
 public:
     /*!
      * \brief Default destructor.
@@ -147,7 +139,7 @@ public:
      * to exchange synchronization data between acquisition and tracking blocks.
      * \param p_gnss_synchro Satellite information shared by the processing blocks.
      */
-    void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
+    inline void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
     {
         d_gnss_synchro = p_gnss_synchro;
     }
@@ -155,7 +147,7 @@ public:
     /*!
      * \brief Returns the maximum peak of grid search.
      */
-    unsigned int mag()
+    inline unsigned int mag() const
     {
         return d_test_statistics;
     }
@@ -169,14 +161,14 @@ public:
      * \brief Sets local code for PCPS acquisition algorithm.
      * \param code - Pointer to the PRN code.
      */
-    void set_local_code(std::complex<float> * code);
+    void set_local_code(std::complex<float>* code);
 
     /*!
      * \brief Starts acquisition algorithm, turning from standby mode to
      * active mode
      * \param active - bool that activates/deactivates the block.
      */
-    void set_active(bool active)
+    inline void set_active(bool active)
     {
         d_active = active;
     }
@@ -185,9 +177,10 @@ public:
      * \brief Set acquisition channel unique ID
      * \param channel - receiver channel.
      */
-    void set_channel(unsigned int channel)
+    inline void set_channel(unsigned int channel)
     {
         d_channel = channel;
+        d_dump_channel = d_channel;
     }
 
     /*!
@@ -195,7 +188,7 @@ public:
      * \param threshold - Threshold for signal detection (check \ref Navitec2012,
      * Algorithm 1, for a definition of this threshold).
      */
-    void set_threshold(float threshold)
+    inline void set_threshold(float threshold)
     {
         d_threshold = threshold;
     }
@@ -204,7 +197,7 @@ public:
      * \brief Set maximum Doppler grid search
      * \param doppler_max - Maximum Doppler shift considered in the grid search [Hz].
      */
-    void set_doppler_max(unsigned int doppler_max)
+    inline void set_doppler_max(unsigned int doppler_max)
     {
         d_config_doppler_max = doppler_max;
     }
@@ -215,16 +208,29 @@ public:
      */
     void set_doppler_step(unsigned int doppler_step);
 
+    /*!
+      * \brief If set to 1, ensures that acquisition starts at the
+      * first available sample.
+      * \param state - int=1 forces start of acquisition
+      */
+    void set_state(int state);
 
     /*!
      * \brief Parallel Code Phase Search Acquisition signal processing.
      */
-    int general_work(int noutput_items, gr_vector_int &ninput_items,
-            gr_vector_const_void_star &input_items,
-            gr_vector_void_star &output_items);
+    int general_work(int noutput_items, gr_vector_int& ninput_items,
+        gr_vector_const_void_star& input_items,
+        gr_vector_void_star& output_items);
 
-    void forecast (int noutput_items, gr_vector_int &ninput_items_required);
+    void forecast(int noutput_items, gr_vector_int& ninput_items_required);
 
+    /*!
+     * \brief Obtains the next power of 2 greater or equal to the input parameter
+     * \param n - Integer value to obtain the next power of 2.
+     */
+    unsigned int nextPowerOf2(unsigned int n);
+
+    void dump_results(int effective_fft_size);
 };
 
 #endif /* pcps_acquisition_fine_doppler_cc*/
