@@ -14,7 +14,7 @@
  *
  * Kay Borre book: K.Borre, D.M.Akos, N.Bertelsen, P.Rinder, and S.H.Jensen,
  * "A Software-Defined GPS and Galileo Receiver. A Single-Frequency
- * Approach", Birkha user, 2007. pp 81-84
+ * Approach", Birkhauser, 2007. pp 81-84
  *
  * \authors <ul>
  *          <li> Javier Arribas, 2013. jarribas(at)cttc.es
@@ -22,7 +22,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -40,7 +40,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -48,22 +48,27 @@
 #ifndef GNSS_SDR_PCPS_ASSISTED_ACQUISITION_CC_H_
 #define GNSS_SDR_PCPS_ASSISTED_ACQUISITION_CC_H_
 
+#include "gnss_synchro.h"
+#include <gnuradio/block.h>
+#include <gnuradio/fft/fft.h>
+#include <gnuradio/gr_complex.h>
 #include <fstream>
 #include <string>
-#include <gnuradio/block.h>
-#include <gnuradio/gr_complex.h>
-#include <gnuradio/fft/fft.h>
-#include "gnss_synchro.h"
 
 class pcps_assisted_acquisition_cc;
 
 typedef boost::shared_ptr<pcps_assisted_acquisition_cc>
-pcps_assisted_acquisition_cc_sptr;
+    pcps_assisted_acquisition_cc_sptr;
 
 pcps_assisted_acquisition_cc_sptr
-pcps_make_assisted_acquisition_cc(int max_dwells, unsigned int sampled_ms,
-        int doppler_max, int doppler_min, long freq, long fs_in, int samples_per_ms,
-        bool dump, std::string dump_filename);
+pcps_make_assisted_acquisition_cc(
+    int32_t max_dwells,
+    uint32_t sampled_ms,
+    int32_t doppler_max,
+    int32_t doppler_min,
+    int64_t fs_in,
+    int32_t samples_per_ms,
+    bool dump, std::string dump_filename);
 
 /*!
  * \brief This class implements a Parallel Code Phase Search Acquisition.
@@ -71,49 +76,48 @@ pcps_make_assisted_acquisition_cc(int max_dwells, unsigned int sampled_ms,
  * Check \ref Navitec2012 "An Open Source Galileo E1 Software Receiver",
  * Algorithm 1, for a pseudocode description of this implementation.
  */
-class pcps_assisted_acquisition_cc: public gr::block
+class pcps_assisted_acquisition_cc : public gr::block
 {
 private:
     friend pcps_assisted_acquisition_cc_sptr
-    pcps_make_assisted_acquisition_cc(int max_dwells, unsigned int sampled_ms,
-            int doppler_max, int doppler_min, long freq, long fs_in,
-            int samples_per_ms, bool dump,
-            std::string dump_filename);
+    pcps_make_assisted_acquisition_cc(int32_t max_dwells, uint32_t sampled_ms,
+        int32_t doppler_max, int32_t doppler_min, int64_t fs_in,
+        int32_t samples_per_ms, bool dump,
+        std::string dump_filename);
 
-    pcps_assisted_acquisition_cc(int max_dwells, unsigned int sampled_ms,
-            int doppler_max, int doppler_min, long freq, long fs_in,
-            int samples_per_ms, bool dump,
-            std::string dump_filename);
+    pcps_assisted_acquisition_cc(int32_t max_dwells, uint32_t sampled_ms,
+        int32_t doppler_max, int32_t doppler_min, int64_t fs_in,
+        int32_t samples_per_ms, bool dump,
+        std::string dump_filename);
 
-    void calculate_magnitudes(gr_complex* fft_begin, int doppler_shift,
-            int doppler_offset);
+    void calculate_magnitudes(gr_complex* fft_begin, int32_t doppler_shift,
+        int32_t doppler_offset);
 
-    int compute_and_accumulate_grid(gr_vector_const_void_star &input_items);
-    float estimate_input_power(gr_vector_const_void_star &input_items);
+    int32_t compute_and_accumulate_grid(gr_vector_const_void_star& input_items);
+    float estimate_input_power(gr_vector_const_void_star& input_items);
     double search_maximum();
     void get_assistance();
     void reset_grid();
     void redefine_grid();
     void free_grid_memory();
 
-    long d_fs_in;
-    long d_freq;
-    int d_samples_per_ms;
-    int d_max_dwells;
-    unsigned int d_doppler_resolution;
-    int d_gnuradio_forecast_samples;
+    int64_t d_fs_in;
+    int32_t d_samples_per_ms;
+    int32_t d_max_dwells;
+    uint32_t d_doppler_resolution;
+    int32_t d_gnuradio_forecast_samples;
     float d_threshold;
     std::string d_satellite_str;
-    int d_doppler_max;
-    int d_doppler_min;
-    int d_config_doppler_max;
-    int d_config_doppler_min;
+    int32_t d_doppler_max;
+    int32_t d_doppler_min;
+    int32_t d_config_doppler_max;
+    int32_t d_config_doppler_min;
 
-    int d_num_doppler_points;
-    int d_doppler_step;
-    unsigned int d_sampled_ms;
-    unsigned int d_fft_size;
-    unsigned long int d_sample_counter;
+    int32_t d_num_doppler_points;
+    int32_t d_doppler_step;
+    uint32_t d_sampled_ms;
+    uint32_t d_fft_size;
+    uint64_t d_sample_counter;
     gr_complex* d_carrier;
     gr_complex* d_fft_codes;
 
@@ -122,18 +126,18 @@ private:
 
     gr::fft::fft_complex* d_fft_if;
     gr::fft::fft_complex* d_ifft;
-    Gnss_Synchro *d_gnss_synchro;
-    unsigned int d_code_phase;
+    Gnss_Synchro* d_gnss_synchro;
+    uint32_t d_code_phase;
     float d_doppler_freq;
     float d_input_power;
     float d_test_statistics;
     std::ofstream d_dump_file;
-    int d_state;
+    int32_t d_state;
     bool d_active;
     bool d_disable_assist;
-    int d_well_count;
+    int32_t d_well_count;
     bool d_dump;
-    unsigned int d_channel;
+    uint32_t d_channel;
 
     std::string d_dump_filename;
 
@@ -148,7 +152,7 @@ public:
      * to exchange synchronization data between acquisition and tracking blocks.
      * \param p_gnss_synchro Satellite information shared by the processing blocks.
      */
-    void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
+    inline void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
     {
         d_gnss_synchro = p_gnss_synchro;
     }
@@ -156,7 +160,7 @@ public:
     /*!
      * \brief Returns the maximum peak of grid search.
      */
-    unsigned int mag()
+    inline uint32_t mag() const
     {
         return d_test_statistics;
     }
@@ -170,14 +174,14 @@ public:
      * \brief Sets local code for PCPS acquisition algorithm.
      * \param code - Pointer to the PRN code.
      */
-    void set_local_code(std::complex<float> * code);
+    void set_local_code(std::complex<float>* code);
 
     /*!
      * \brief Starts acquisition algorithm, turning from standby mode to
      * active mode
      * \param active - bool that activates/deactivates the block.
      */
-    void set_active(bool active)
+    inline void set_active(bool active)
     {
         d_active = active;
     }
@@ -186,7 +190,7 @@ public:
      * \brief Set acquisition channel unique ID
      * \param channel - receiver channel.
      */
-    void set_channel(unsigned int channel)
+    inline void set_channel(uint32_t channel)
     {
         d_channel = channel;
     }
@@ -196,7 +200,7 @@ public:
      * \param threshold - Threshold for signal detection (check \ref Navitec2012,
      * Algorithm 1, for a definition of this threshold).
      */
-    void set_threshold(float threshold)
+    inline void set_threshold(float threshold)
     {
         d_threshold = threshold;
     }
@@ -205,7 +209,7 @@ public:
      * \brief Set maximum Doppler grid search
      * \param doppler_max - Maximum Doppler shift considered in the grid search [Hz].
      */
-    void set_doppler_max(unsigned int doppler_max)
+    inline void set_doppler_max(uint32_t doppler_max)
     {
         d_doppler_max = doppler_max;
     }
@@ -214,17 +218,16 @@ public:
      * \brief Set Doppler steps for the grid search
      * \param doppler_step - Frequency bin of the search grid [Hz].
      */
-    void set_doppler_step(unsigned int doppler_step);
-
+    void set_doppler_step(uint32_t doppler_step);
 
     /*!
      * \brief Parallel Code Phase Search Acquisition signal processing.
      */
-    int general_work(int noutput_items, gr_vector_int &ninput_items,
-            gr_vector_const_void_star &input_items,
-            gr_vector_void_star &output_items);
+    int general_work(int noutput_items, gr_vector_int& ninput_items,
+        gr_vector_const_void_star& input_items,
+        gr_vector_void_star& output_items);
 
-    void forecast (int noutput_items, gr_vector_int &ninput_items_required);
+    void forecast(int noutput_items, gr_vector_int& ninput_items_required);
 };
 
 #endif /* GNSS_SDR_PCPS_assisted_acquisition_cc_H_*/
