@@ -25,7 +25,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -43,7 +43,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -51,19 +51,20 @@
 #ifndef GNSS_SDR_PCPS_OPENCL_ACQUISITION_CC_H_
 #define GNSS_SDR_PCPS_OPENCL_ACQUISITION_CC_H_
 
+#include "gnss_synchro.h"
+#include "opencl/fft_internal.h"
+#include <gnuradio/block.h>
+#include <gnuradio/fft/fft.h>
+#include <gnuradio/gr_complex.h>
+#include <cstdint>
 #include <fstream>
 #include <string>
 #include <vector>
-#include <gnuradio/block.h>
-#include <gnuradio/gr_complex.h>
-#include <gnuradio/fft/fft.h>
-#include "fft_internal.h"
-#include "gnss_synchro.h"
 
 #ifdef __APPLE__
-   #include "cl.hpp"
+#include "opencl/cl.hpp"
 #else
-    #include <CL/cl.hpp>
+#include <CL/cl.hpp>
 #endif
 
 class pcps_opencl_acquisition_cc;
@@ -71,12 +72,12 @@ class pcps_opencl_acquisition_cc;
 typedef boost::shared_ptr<pcps_opencl_acquisition_cc> pcps_opencl_acquisition_cc_sptr;
 
 pcps_opencl_acquisition_cc_sptr
-pcps_make_opencl_acquisition_cc(unsigned int sampled_ms, unsigned int max_dwells,
-                         unsigned int doppler_max, long freq, long fs_in,
-                         int samples_per_ms, int samples_per_code,
-                         bool bit_transition_flag,
-                         bool dump,
-                         std::string dump_filename);
+pcps_make_opencl_acquisition_cc(uint32_t sampled_ms, uint32_t max_dwells,
+    uint32_t doppler_max, int64_t fs_in,
+    int samples_per_ms, int samples_per_code,
+    bool bit_transition_flag,
+    bool dump,
+    std::string dump_filename);
 
 /*!
  * \brief This class implements a Parallel Code Phase Search Acquisition.
@@ -84,52 +85,51 @@ pcps_make_opencl_acquisition_cc(unsigned int sampled_ms, unsigned int max_dwells
  * Check \ref Navitec2012 "An Open Source Galileo E1 Software Receiver",
  * Algorithm 1, for a pseudocode description of this implementation.
  */
-class pcps_opencl_acquisition_cc: public gr::block
+class pcps_opencl_acquisition_cc : public gr::block
 {
 private:
     friend pcps_opencl_acquisition_cc_sptr
-    pcps_make_opencl_acquisition_cc(unsigned int sampled_ms, unsigned int max_dwells,
-            unsigned int doppler_max, long freq, long fs_in,
-            int samples_per_ms, int samples_per_code,
-            bool bit_transition_flag,
-            bool dump,
-            std::string dump_filename);
+    pcps_make_opencl_acquisition_cc(uint32_t sampled_ms, uint32_t max_dwells,
+        uint32_t doppler_max, int64_t fs_in,
+        int samples_per_ms, int samples_per_code,
+        bool bit_transition_flag,
+        bool dump,
+        std::string dump_filename);
 
-    pcps_opencl_acquisition_cc(unsigned int sampled_ms, unsigned int max_dwells,
-            unsigned int doppler_max, long freq, long fs_in,
-            int samples_per_ms, int samples_per_code,
-            bool bit_transition_flag,
-            bool dump,
-            std::string dump_filename);
+    pcps_opencl_acquisition_cc(uint32_t sampled_ms, uint32_t max_dwells,
+        uint32_t doppler_max, int64_t fs_in,
+        int samples_per_ms, int samples_per_code,
+        bool bit_transition_flag,
+        bool dump,
+        std::string dump_filename);
 
     void calculate_magnitudes(gr_complex* fft_begin, int doppler_shift,
-            int doppler_offset);
+        int doppler_offset);
 
-    int init_opencl_environment(std::string kernel_filename);
+    int init_opencl_environment(const std::string& kernel_filename);
 
-    long d_fs_in;
-    long d_freq;
+    int64_t d_fs_in;
     int d_samples_per_ms;
     int d_samples_per_code;
-    unsigned int d_doppler_resolution;
+    uint32_t d_doppler_resolution;
     float d_threshold;
     std::string d_satellite_str;
-    unsigned int d_doppler_max;
-    unsigned int d_doppler_step;
-    unsigned int d_sampled_ms;
-    unsigned int d_max_dwells;
-    unsigned int d_well_count;
-    unsigned int d_fft_size;
-    unsigned int d_fft_size_pow2;
+    uint32_t d_doppler_max;
+    uint32_t d_doppler_step;
+    uint32_t d_sampled_ms;
+    uint32_t d_max_dwells;
+    uint32_t d_well_count;
+    uint32_t d_fft_size;
+    uint32_t d_fft_size_pow2;
     int* d_max_doppler_indexs;
-    unsigned long int d_sample_counter;
+    uint64_t d_sample_counter;
     gr_complex** d_grid_doppler_wipeoffs;
-    unsigned int d_num_doppler_bins;
+    uint32_t d_num_doppler_bins;
     gr_complex* d_fft_codes;
     gr::fft::fft_complex* d_fft_if;
     gr::fft::fft_complex* d_ifft;
-    Gnss_Synchro *d_gnss_synchro;
-    unsigned int d_code_phase;
+    Gnss_Synchro* d_gnss_synchro;
+    uint32_t d_code_phase;
     float d_doppler_freq;
     float d_mag;
     float* d_magnitude;
@@ -141,12 +141,12 @@ private:
     int d_state;
     bool d_core_working;
     bool d_dump;
-    unsigned int d_channel;
+    uint32_t d_channel;
     std::string d_dump_filename;
     gr_complex* d_zero_vector;
     gr_complex** d_in_buffer;
-    std::vector<unsigned long int> d_sample_counter_buffer;
-    unsigned int d_in_dwell_count;
+    std::vector<uint64_t> d_sample_counter_buffer;
+    uint32_t d_in_dwell_count;
 
     cl::Platform d_cl_platform;
     cl::Device d_cl_device;
@@ -168,101 +168,101 @@ public:
     /*!
      * \brief Default destructor.
      */
-     ~pcps_opencl_acquisition_cc();
+    ~pcps_opencl_acquisition_cc();
 
-     /*!
+    /*!
       * \brief Set acquisition/tracking common Gnss_Synchro object pointer
       * to exchange synchronization data between acquisition and tracking blocks.
       * \param p_gnss_synchro Satellite information shared by the processing blocks.
       */
-     void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
-     {
-         d_gnss_synchro = p_gnss_synchro;
-     }
+    inline void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
+    {
+        d_gnss_synchro = p_gnss_synchro;
+    }
 
-     /*!
+    /*!
       * \brief Returns the maximum peak of grid search.
       */
-     unsigned int mag()
-     {
-         return d_mag;
-     }
+    inline uint32_t mag() const
+    {
+        return d_mag;
+    }
 
-     /*!
+    /*!
       * \brief Initializes acquisition algorithm.
       */
-     void init();
+    void init();
 
-     /*!
+    /*!
       * \brief Sets local code for PCPS acquisition algorithm.
       * \param code - Pointer to the PRN code.
       */
-     void set_local_code(std::complex<float> * code);
+    void set_local_code(std::complex<float>* code);
 
-     /*!
+    /*!
       * \brief Starts acquisition algorithm, turning from standby mode to
       * active mode
       * \param active - bool that activates/deactivates the block.
       */
-     void set_active(bool active)
-     {
-         d_active = active;
-     }
+    inline void set_active(bool active)
+    {
+        d_active = active;
+    }
 
-     /*!
+    /*!
       * \brief If set to 1, ensures that acquisition starts at the
       * first available sample.
       * \param state - int=1 forces start of acquisition
       */
-     void set_state(int state);
+    void set_state(int state);
 
-     /*!
+    /*!
       * \brief Set acquisition channel unique ID
       * \param channel - receiver channel.
       */
-     void set_channel(unsigned int channel)
-     {
-         d_channel = channel;
-     }
+    inline void set_channel(uint32_t channel)
+    {
+        d_channel = channel;
+    }
 
-     /*!
+    /*!
       * \brief Set statistics threshold of PCPS algorithm.
       * \param threshold - Threshold for signal detection (check \ref Navitec2012,
       * Algorithm 1, for a definition of this threshold).
       */
-     void set_threshold(float threshold)
-     {
-         d_threshold = threshold;
-     }
+    inline void set_threshold(float threshold)
+    {
+        d_threshold = threshold;
+    }
 
-     /*!
+    /*!
       * \brief Set maximum Doppler grid search
       * \param doppler_max - Maximum Doppler shift considered in the grid search [Hz].
       */
-     void set_doppler_max(unsigned int doppler_max)
-     {
-         d_doppler_max = doppler_max;
-     }
+    inline void set_doppler_max(uint32_t doppler_max)
+    {
+        d_doppler_max = doppler_max;
+    }
 
-     /*!
+    /*!
       * \brief Set Doppler steps for the grid search
       * \param doppler_step - Frequency bin of the search grid [Hz].
       */
-     void set_doppler_step(unsigned int doppler_step)
-     {
-         d_doppler_step = doppler_step;
-     }
+    inline void set_doppler_step(uint32_t doppler_step)
+    {
+        d_doppler_step = doppler_step;
+    }
 
-     /*!
+    /*!
       * \brief Parallel Code Phase Search Acquisition signal processing.
       */
-     int general_work(int noutput_items, gr_vector_int &ninput_items,
-             gr_vector_const_void_star &input_items,
-             gr_vector_void_star &output_items);
+    int general_work(int noutput_items, gr_vector_int& ninput_items,
+        gr_vector_const_void_star& input_items,
+        gr_vector_void_star& output_items);
 
-     void acquisition_core_volk();
+    void acquisition_core_volk();
 
-     void acquisition_core_opencl();
+    void acquisition_core_opencl();
 };
 
 #endif
