@@ -25,7 +25,7 @@
 *
 * -------------------------------------------------------------------------
 *
-* Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+* Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
 *
 * GNSS-SDR is a software defined Global Navigation
 *          Satellite Systems receiver
@@ -43,7 +43,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+* along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------
 */
@@ -51,29 +51,33 @@
 #ifndef GNSS_SDR_PCPS_QUICKSYNC_ACQUISITION_CC_H_
 #define GNSS_SDR_PCPS_QUICKSYNC_ACQUISITION_CC_H_
 
-#include <fstream>
-#include <string>
-#include <algorithm>
-#include <functional>
-#include <assert.h>
-#include <gnuradio/block.h>
-#include <gnuradio/gr_complex.h>
-#include <gnuradio/fft/fft.h>
 #include "gnss_synchro.h"
+#include <gnuradio/block.h>
+#include <gnuradio/fft/fft.h>
+#include <gnuradio/gr_complex.h>
+#include <algorithm>
+#include <cassert>
+#include <fstream>
+#include <functional>
+#include <string>
 
 class pcps_quicksync_acquisition_cc;
 
 typedef boost::shared_ptr<pcps_quicksync_acquisition_cc>
-pcps_quicksync_acquisition_cc_sptr;
+    pcps_quicksync_acquisition_cc_sptr;
 
 pcps_quicksync_acquisition_cc_sptr
-pcps_quicksync_make_acquisition_cc(unsigned int folding_factor,
-        unsigned int sampled_ms, unsigned int max_dwells,
-        unsigned int doppler_max, long freq, long fs_in,
-        int samples_per_ms, int samples_per_code,
-        bool bit_transition_flag,
-        bool dump,
-        std::string dump_filename);
+pcps_quicksync_make_acquisition_cc(
+    uint32_t folding_factor,
+    uint32_t sampled_ms,
+    uint32_t max_dwells,
+    uint32_t doppler_max,
+    int64_t fs_in,
+    int32_t samples_per_ms,
+    int32_t samples_per_code,
+    bool bit_transition_flag,
+    bool dump,
+    std::string dump_filename);
 
 /*!
  * \brief This class implements a Parallel Code Phase Search Acquisition with
@@ -82,61 +86,60 @@ pcps_quicksync_make_acquisition_cc(unsigned int folding_factor,
  * Check \ref Navitec2012 "Faster GPS via the Sparse Fourier Transform",
  * for details of its implementation and functionality.
  */
-class pcps_quicksync_acquisition_cc: public gr::block
+class pcps_quicksync_acquisition_cc : public gr::block
 {
 private:
     friend pcps_quicksync_acquisition_cc_sptr
-    pcps_quicksync_make_acquisition_cc(unsigned int folding_factor,
-            unsigned int sampled_ms, unsigned int max_dwells,
-            unsigned int doppler_max, long freq, long fs_in,
-            int samples_per_ms, int samples_per_code,
-            bool bit_transition_flag,
-            bool dump,
-            std::string dump_filename);
+    pcps_quicksync_make_acquisition_cc(uint32_t folding_factor,
+        uint32_t sampled_ms, uint32_t max_dwells,
+        uint32_t doppler_max, int64_t fs_in,
+        int32_t samples_per_ms, int32_t samples_per_code,
+        bool bit_transition_flag,
+        bool dump,
+        std::string dump_filename);
 
-    pcps_quicksync_acquisition_cc(unsigned int folding_factor,
-            unsigned int sampled_ms, unsigned int max_dwells,
-            unsigned int doppler_max, long freq, long fs_in,
-            int samples_per_ms, int samples_per_code,
-            bool bit_transition_flag,
-            bool dump,
-            std::string dump_filename);
+    pcps_quicksync_acquisition_cc(uint32_t folding_factor,
+        uint32_t sampled_ms, uint32_t max_dwells,
+        uint32_t doppler_max, int64_t fs_in,
+        int32_t samples_per_ms, int32_t samples_per_code,
+        bool bit_transition_flag,
+        bool dump,
+        std::string dump_filename);
 
-    void calculate_magnitudes(gr_complex* fft_begin, int doppler_shift,
-            int doppler_offset);
+    void calculate_magnitudes(gr_complex* fft_begin, int32_t doppler_shift,
+        int32_t doppler_offset);
 
     gr_complex* d_code;
-    unsigned int d_folding_factor; // also referred in the paper as 'p'
+    uint32_t d_folding_factor;  // also referred in the paper as 'p'
     float* d_corr_acumulator;
-    unsigned int* d_possible_delay;
+    uint32_t* d_possible_delay;
     float* d_corr_output_f;
     float* d_magnitude_folded;
     gr_complex* d_signal_folded;
     gr_complex* d_code_folded;
     float d_noise_floor_power;
 
-    long d_fs_in;
-    long d_freq;
-    int d_samples_per_ms;
-    int d_samples_per_code;
-    unsigned int d_doppler_resolution;
+    int64_t d_fs_in;
+    int32_t d_samples_per_ms;
+    int32_t d_samples_per_code;
+    uint32_t d_doppler_resolution;
     float d_threshold;
     std::string d_satellite_str;
-    unsigned int d_doppler_max;
-    unsigned int d_doppler_step;
-    unsigned int d_sampled_ms;
-    unsigned int d_max_dwells;
-    unsigned int d_well_count;
-    unsigned int d_fft_size;
-    unsigned long int d_sample_counter;
+    uint32_t d_doppler_max;
+    uint32_t d_doppler_step;
+    uint32_t d_sampled_ms;
+    uint32_t d_max_dwells;
+    uint32_t d_well_count;
+    uint32_t d_fft_size;
+    uint64_t d_sample_counter;
     gr_complex** d_grid_doppler_wipeoffs;
-    unsigned int d_num_doppler_bins;
+    uint32_t d_num_doppler_bins;
     gr_complex* d_fft_codes;
     gr::fft::fft_complex* d_fft_if;
     gr::fft::fft_complex* d_fft_if2;
     gr::fft::fft_complex* d_ifft;
-    Gnss_Synchro *d_gnss_synchro;
-    unsigned int d_code_phase;
+    Gnss_Synchro* d_gnss_synchro;
+    uint32_t d_code_phase;
     float d_doppler_freq;
     float d_mag;
     float* d_magnitude;
@@ -145,9 +148,9 @@ private:
     bool d_bit_transition_flag;
     std::ofstream d_dump_file;
     bool d_active;
-    int d_state;
+    int32_t d_state;
     bool d_dump;
-    unsigned int d_channel;
+    uint32_t d_channel;
     std::string d_dump_filename;
 
 public:
@@ -161,7 +164,7 @@ public:
      * to exchange synchronization data between acquisition and tracking blocks.
      * \param p_gnss_synchro Satellite information shared by the processing blocks.
      */
-    void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
+    inline void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
     {
         d_gnss_synchro = p_gnss_synchro;
     }
@@ -169,7 +172,7 @@ public:
     /*!
      * \brief Returns the maximum peak of grid search.
      */
-    unsigned int mag()
+    inline uint32_t mag() const
     {
         return d_mag;
     }
@@ -183,14 +186,14 @@ public:
      * \brief Sets local code for PCPS acquisition algorithm.
      * \param code - Pointer to the PRN code.
      */
-    void set_local_code(std::complex<float> * code);
+    void set_local_code(std::complex<float>* code);
 
     /*!
      * \brief Starts acquisition algorithm, turning from standby mode to
      * active mode
      * \param active - bool that activates/deactivates the block.
      */
-    void set_active(bool active)
+    inline void set_active(bool active)
     {
         d_active = active;
     }
@@ -200,13 +203,13 @@ public:
      * first available sample.
      * \param state - int=1 forces start of acquisition
      */
-    void set_state(int state);
+    void set_state(int32_t state);
 
     /*!
      * \brief Set acquisition channel unique ID
      * \param channel - receiver channel.
      */
-    void set_channel(unsigned int channel)
+    inline void set_channel(uint32_t channel)
     {
         d_channel = channel;
     }
@@ -216,7 +219,7 @@ public:
      * \param threshold - Threshold for signal detection (check \ref Navitec2012,
      * Algorithm 1, for a definition of this threshold).
      */
-    void set_threshold(float threshold)
+    inline void set_threshold(float threshold)
     {
         d_threshold = threshold;
     }
@@ -225,7 +228,7 @@ public:
      * \brief Set maximum Doppler grid search
      * \param doppler_max - Maximum Doppler shift considered in the grid search [Hz].
      */
-    void set_doppler_max(unsigned int doppler_max)
+    inline void set_doppler_max(uint32_t doppler_max)
     {
         d_doppler_max = doppler_max;
     }
@@ -234,18 +237,17 @@ public:
      * \brief Set Doppler steps for the grid search
      * \param doppler_step - Frequency bin of the search grid [Hz].
      */
-    void set_doppler_step(unsigned int doppler_step)
+    inline void set_doppler_step(uint32_t doppler_step)
     {
         d_doppler_step = doppler_step;
     }
 
-
     /*!
      * \brief Parallel Code Phase Search Acquisition signal processing.
      */
-    int general_work(int noutput_items, gr_vector_int &ninput_items,
-            gr_vector_const_void_star &input_items,
-            gr_vector_void_star &output_items);
+    int general_work(int noutput_items, gr_vector_int& ninput_items,
+        gr_vector_const_void_star& input_items,
+        gr_vector_void_star& output_items);
 };
 
 #endif /* GNSS_SDR_PCPS_ACQUISITION_CC_H_*/
