@@ -9,7 +9,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -27,7 +27,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -35,14 +35,15 @@
 #ifndef GNSS_SDR_CHANNEL_H_
 #define GNSS_SDR_CHANNEL_H_
 
-#include <memory>
-#include <string>
-#include <gnuradio/msg_queue.h>
-#include <gnuradio/block.h>
-#include "channel_interface.h"
 #include "channel_fsm.h"
-#include "gnss_synchro.h"
+#include "channel_interface.h"
 #include "channel_msg_receiver_cc.h"
+#include "gnss_synchro.h"
+#include <gnuradio/block.h>
+#include <gnuradio/msg_queue.h>
+#include <memory>
+#include <mutex>
+#include <string>
 
 class ConfigurationInterface;
 class AcquisitionInterface;
@@ -55,52 +56,53 @@ class TelemetryDecoderInterface;
  * their interaction through a Finite State Machine
  *
  */
-class Channel: public ChannelInterface
+class Channel : public ChannelInterface
 {
-
 public:
     //! Constructor
-    Channel(ConfigurationInterface *configuration, unsigned int channel,
-            std::shared_ptr<GNSSBlockInterface> pass_through, std::shared_ptr<AcquisitionInterface> acq,
-            std::shared_ptr<TrackingInterface> trk, std::shared_ptr<TelemetryDecoderInterface> nav,
-            std::string role, std::string implementation,
-            boost::shared_ptr<gr::msg_queue> queue);
+    Channel(ConfigurationInterface* configuration, uint32_t channel, std::shared_ptr<AcquisitionInterface> acq,
+        std::shared_ptr<TrackingInterface> trk, std::shared_ptr<TelemetryDecoderInterface> nav,
+        std::string role, std::string implementation, gr::msg_queue::sptr queue);
     //! Virtual destructor
     virtual ~Channel();
-    void connect(gr::top_block_sptr top_block);
-    void disconnect(gr::top_block_sptr top_block);
-    gr::basic_block_sptr get_left_block();
-    gr::basic_block_sptr get_right_block();
-    std::string role(){ return role_; }
 
+    void connect(gr::top_block_sptr top_block) override;  //!< connects the tracking block to the top_block and to the telemetry
+    void disconnect(gr::top_block_sptr top_block) override;
+    gr::basic_block_sptr get_left_block() override;      //!< gets the gnuradio tracking block pointer
+    gr::basic_block_sptr get_left_block_trk() override;  //!< gets the gnuradio tracking block pointer
+    gr::basic_block_sptr get_left_block_acq() override;  //!< gets the gnuradio tracking block pointer
+    gr::basic_block_sptr get_right_block() override;
+
+    inline std::string role() override { return role_; }
     //! Returns "Channel"
-    std::string implementation(){ return implementation_; }
-    size_t item_size(){ return 0; }
-    Gnss_Signal get_signal() const { return gnss_signal_; }
-    std::shared_ptr<AcquisitionInterface> acquisition(){ return acq_; }
-    std::shared_ptr<TrackingInterface> tracking(){ return trk_; }
-    std::shared_ptr<TelemetryDecoderInterface> telemetry(){ return nav_; }
-    void start_acquisition();                   //!< Start the State Machine
-    void set_signal(const Gnss_Signal& gnss_signal_);  //!< Sets the channel GNSS signal
+    inline std::string implementation() override { return implementation_; }
+    inline size_t item_size() override { return 0; }
+    inline Gnss_Signal get_signal() const override { return gnss_signal_; }
+    void start_acquisition() override;                          //!< Start the State Machine
+    void stop_channel() override;                               //!< Stop the State Machine
+    void set_signal(const Gnss_Signal& gnss_signal_) override;  //!< Sets the channel GNSS signal
 
+    inline std::shared_ptr<AcquisitionInterface> acquisition() { return acq_; }
+    inline std::shared_ptr<TrackingInterface> tracking() { return trk_; }
+    inline std::shared_ptr<TelemetryDecoderInterface> telemetry() { return nav_; }
     void msg_handler_events(pmt::pmt_t msg);
 
-
 private:
     channel_msg_receiver_cc_sptr channel_msg_rx;
-    std::shared_ptr<GNSSBlockInterface> pass_through_;
     std::shared_ptr<AcquisitionInterface> acq_;
     std::shared_ptr<TrackingInterface> trk_;
     std::shared_ptr<TelemetryDecoderInterface> nav_;
     std::string role_;
     std::string implementation_;
-    unsigned int channel_;
+    bool flag_enable_fpga;
+    uint32_t channel_;
     Gnss_Synchro gnss_synchro_;
     Gnss_Signal gnss_signal_;
     bool connected_;
     bool repeat_;
-    ChannelFsm channel_fsm_;
-    boost::shared_ptr<gr::msg_queue> queue_;
+    std::shared_ptr<ChannelFsm> channel_fsm_;
+    gr::msg_queue::sptr queue_;
+    std::mutex mx;
 };
 
 #endif /*GNSS_SDR_CHANNEL_H_*/
