@@ -6,7 +6,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -24,7 +24,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -33,9 +33,9 @@
 #define GNSS_SDR_ARRAY_SIGNAL_CONDITIONER_H_
 
 
-#include <string>
-#include <gnuradio/msg_queue.h>
 #include "gnss_block_interface.h"
+#include <gnuradio/msg_queue.h>
+#include <string>
 
 
 class ConfigurationInterface;
@@ -47,30 +47,30 @@ class TelemetryDecoderInterface;
  * \brief This class wraps blocks to change data_type_adapter, input_filter and resampler
  * to be applied to the input flow of sampled signal.
  */
-class ArraySignalConditioner: public GNSSBlockInterface
+class ArraySignalConditioner : public GNSSBlockInterface
 {
 public:
     //! Constructor
     ArraySignalConditioner(ConfigurationInterface *configuration,
-            std::shared_ptr<GNSSBlockInterface> data_type_adapt, std::shared_ptr<GNSSBlockInterface> in_filt,
-            std::shared_ptr<GNSSBlockInterface> res, std::string role, std::string implementation);
+        std::shared_ptr<GNSSBlockInterface> data_type_adapt, std::shared_ptr<GNSSBlockInterface> in_filt,
+        std::shared_ptr<GNSSBlockInterface> res, std::string role, std::string implementation);
 
     //! Virtual destructor
     virtual ~ArraySignalConditioner();
 
-    void connect(gr::top_block_sptr top_block);
-    void disconnect(gr::top_block_sptr top_block);
-    gr::basic_block_sptr get_left_block();
-    gr::basic_block_sptr get_right_block();
+    void connect(gr::top_block_sptr top_block) override;
+    void disconnect(gr::top_block_sptr top_block) override;
+    gr::basic_block_sptr get_left_block() override;
+    gr::basic_block_sptr get_right_block() override;
 
-    std::string role(){ return role_; }
-    //! Returns "Signal_Conditioner"
-    std::string implementation(){ return "Array_Signal_Conditioner"; }
-    size_t item_size(){ return 0; }
+    inline std::string role() override { return role_; }
+    //! Returns "Array_Signal_Conditioner"
+    inline std::string implementation() override { return "Array_Signal_Conditioner"; }
+    inline size_t item_size() override { return 0; }
 
-    std::shared_ptr<GNSSBlockInterface> data_type_adapter(){ return data_type_adapt_; }
-    std::shared_ptr<GNSSBlockInterface> input_filter(){ return in_filt_; }
-    std::shared_ptr<GNSSBlockInterface> resampler(){ return res_; }
+    inline std::shared_ptr<GNSSBlockInterface> data_type_adapter() { return data_type_adapt_; }
+    inline std::shared_ptr<GNSSBlockInterface> input_filter() { return in_filt_; }
+    inline std::shared_ptr<GNSSBlockInterface> resampler() { return res_; }
 
 private:
     std::shared_ptr<GNSSBlockInterface> data_type_adapt_;
@@ -79,7 +79,6 @@ private:
     std::string role_;
     std::string implementation_;
     bool connected_;
-    //bool stop_;
 };
 
 #endif /*GNSS_SDR_SIGNAL_CONDITIONER_H_*/
