@@ -6,7 +6,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -24,32 +24,39 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
 #include "signal_conditioner.h"
 #include <glog/logging.h>
+#include <utility>
 
 
 using google::LogMessage;
 
 // Constructor
 SignalConditioner::SignalConditioner(ConfigurationInterface *configuration,
-        std::shared_ptr<GNSSBlockInterface> data_type_adapt, std::shared_ptr<GNSSBlockInterface> in_filt,
-        std::shared_ptr<GNSSBlockInterface> res, std::string role, std::string implementation) :
-                data_type_adapt_(data_type_adapt),
-                in_filt_(in_filt), res_(res), role_(role), implementation_(implementation)
+    std::shared_ptr<GNSSBlockInterface> data_type_adapt,
+    std::shared_ptr<GNSSBlockInterface> in_filt,
+    std::shared_ptr<GNSSBlockInterface> res,
+    std::string role,
+    std::string implementation) : data_type_adapt_(std::move(data_type_adapt)),
+                                  in_filt_(std::move(in_filt)),
+                                  res_(std::move(res)),
+                                  role_(std::move(role)),
+                                  implementation_(std::move(implementation))
 {
     connected_ = false;
-    if(configuration){ };
+    if (configuration)
+        {
+        };
 }
 
 
 // Destructor
-SignalConditioner::~SignalConditioner()
-{}
+SignalConditioner::~SignalConditioner() = default;
 
 
 void SignalConditioner::connect(gr::top_block_sptr top_block)
@@ -81,9 +88,9 @@ void SignalConditioner::disconnect(gr::top_block_sptr top_block)
         }
 
     top_block->disconnect(data_type_adapt_->get_right_block(), 0,
-                          in_filt_->get_left_block(), 0);
+        in_filt_->get_left_block(), 0);
     top_block->disconnect(in_filt_->get_right_block(), 0,
-                          res_->get_left_block(), 0);
+        res_->get_left_block(), 0);
 
     data_type_adapt_->disconnect(top_block);
     in_filt_->disconnect(top_block);
@@ -98,8 +105,8 @@ gr::basic_block_sptr SignalConditioner::get_left_block()
     return data_type_adapt_->get_left_block();
 }
 
+
 gr::basic_block_sptr SignalConditioner::get_right_block()
 {
     return res_->get_right_block();
 }
-
