@@ -6,7 +6,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -24,22 +24,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
 #include "ibyte_to_cbyte.h"
-#include <volk/volk.h>
-#include <glog/logging.h>
 #include "configuration_interface.h"
+#include <glog/logging.h>
+#include <volk/volk.h>
 
 using google::LogMessage;
 
-IbyteToCbyte::IbyteToCbyte(ConfigurationInterface* configuration, std::string role,
-        unsigned int in_streams, unsigned int out_streams) :
-                config_(configuration), role_(role), in_streams_(in_streams),
-                out_streams_(out_streams)
+IbyteToCbyte::IbyteToCbyte(ConfigurationInterface* configuration, const std::string& role,
+    unsigned int in_streams, unsigned int out_streams) : config_(configuration), role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
     std::string default_input_item_type = "byte";
     std::string default_output_item_type = "lv_8sc_t";
@@ -51,6 +49,7 @@ IbyteToCbyte::IbyteToCbyte(ConfigurationInterface* configuration, std::string ro
 
     dump_ = config_->property(role_ + ".dump", false);
     dump_filename_ = config_->property(role_ + ".dump_filename", default_dump_filename);
+    inverted_spectrum = configuration->property(role + ".inverted_spectrum", false);
 
     size_t item_size = sizeof(lv_8sc_t);
 
@@ -63,18 +62,48 @@ IbyteToCbyte::IbyteToCbyte(ConfigurationInterface* configuration, std::string ro
             DLOG(INFO) << "Dumping output into file " << dump_filename_;
             file_sink_ = gr::blocks::file_sink::make(item_size, dump_filename_.c_str());
         }
+    if (inverted_spectrum)
+        {
+            conjugate_ic_ = make_conjugate_ic();
+        }
+    if (in_streams_ > 1)
+        {
+            LOG(ERROR) << "This implementation only supports one input stream";
+        }
+    if (out_streams_ > 1)
+        {
+            LOG(ERROR) << "This implementation only supports one output stream";
+        }
 }
 
 
-IbyteToCbyte::~IbyteToCbyte()
-{}
+IbyteToCbyte::~IbyteToCbyte() = default;
 
 
 void IbyteToCbyte::connect(gr::top_block_sptr top_block)
 {
     if (dump_)
         {
-            top_block->connect(ibyte_to_cbyte_, 0, file_sink_, 0);
+            if (inverted_spectrum)
+                {
+                    top_block->connect(ibyte_to_cbyte_, 0, conjugate_ic_, 0);
+                    top_block->connect(conjugate_ic_, 0, file_sink_, 0);
+                }
+            else
+                {
+                    top_block->connect(ibyte_to_cbyte_, 0, file_sink_, 0);
+                }
+        }
+    else
+        {
+            if (inverted_spectrum)
+                {
+                    top_block->connect(ibyte_to_cbyte_, 0, conjugate_ic_, 0);
+                }
+            else
+                {
+                    DLOG(INFO) << "Nothing to connect internally";
+                }
         }
 }
 
@@ -83,21 +112,37 @@ void IbyteToCbyte::disconnect(gr::top_block_sptr top_block)
 {
     if (dump_)
         {
-            top_block->disconnect(ibyte_to_cbyte_, 0, file_sink_, 0);
+            if (inverted_spectrum)
+                {
+                    top_block->disconnect(ibyte_to_cbyte_, 0, conjugate_ic_, 0);
+                    top_block->disconnect(conjugate_ic_, 0, file_sink_, 0);
+                }
+            else
+                {
+                    top_block->disconnect(ibyte_to_cbyte_, 0, file_sink_, 0);
+                }
+        }
+    else
+        {
+            if (inverted_spectrum)
+                {
+                    top_block->disconnect(ibyte_to_cbyte_, 0, conjugate_ic_, 0);
+                }
         }
 }
 
 
-
 gr::basic_block_sptr IbyteToCbyte::get_left_block()
 {
     return ibyte_to_cbyte_;
 }
 
 
-
 gr::basic_block_sptr IbyteToCbyte::get_right_block()
 {
+    if (inverted_spectrum)
+        {
+            return conjugate_ic_;
+        }
     return ibyte_to_cbyte_;
 }
-
