@@ -5,7 +5,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -23,7 +23,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -31,11 +31,11 @@
 #ifndef GNSS_SDR_ISHORT_TO_COMPLEX_H_
 #define GNSS_SDR_ISHORT_TO_COMPLEX_H_
 
-#include <string>
-#include <gnuradio/blocks/interleaved_short_to_complex.h>
-#include <gnuradio/blocks/file_sink.h>
+#include "conjugate_cc.h"
 #include "gnss_block_interface.h"
-
+#include <gnuradio/blocks/file_sink.h>
+#include <gnuradio/blocks/interleaved_short_to_complex.h>
+#include <string>
 
 class ConfigurationInterface;
 
@@ -43,33 +43,35 @@ class ConfigurationInterface;
  * \brief Adapts an I/Q interleaved short integer sample stream to a gr_complex (float) stream
  *
  */
-class IshortToComplex: public GNSSBlockInterface
+class IshortToComplex : public GNSSBlockInterface
 {
 public:
     IshortToComplex(ConfigurationInterface* configuration,
-            std::string role, unsigned int in_streams,
-            unsigned int out_streams);
+        const std::string& role, unsigned int in_streams,
+        unsigned int out_streams);
 
     virtual ~IshortToComplex();
 
-    std::string role()
+    inline std::string role() override
     {
         return role_;
     }
+
     //! Returns "Ishort_To_Complex"
-    std::string implementation()
+    inline std::string implementation() override
     {
         return "Ishort_To_Complex";
     }
-    size_t item_size()
+
+    inline size_t item_size() override
     {
         return 0;
     }
 
-    void connect(gr::top_block_sptr top_block);
-    void disconnect(gr::top_block_sptr top_block);
-    gr::basic_block_sptr get_left_block();
-    gr::basic_block_sptr get_right_block();
+    void connect(gr::top_block_sptr top_block) override;
+    void disconnect(gr::top_block_sptr top_block) override;
+    gr::basic_block_sptr get_left_block() override;
+    gr::basic_block_sptr get_right_block() override;
 
 private:
     gr::blocks::interleaved_short_to_complex::sptr gr_interleaved_short_to_complex_;
@@ -82,7 +84,8 @@ private:
     unsigned int in_streams_;
     unsigned int out_streams_;
     gr::blocks::file_sink::sptr file_sink_;
+    conjugate_cc_sptr conjugate_cc_;
+    bool inverted_spectrum;
 };
 
 #endif
-
