@@ -6,7 +6,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -24,22 +24,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
 #include "ishort_to_cshort.h"
+#include "configuration_interface.h"
 #include <glog/logging.h>
 #include <volk/volk.h>
-#include "configuration_interface.h"
 
 using google::LogMessage;
 
-IshortToCshort::IshortToCshort(ConfigurationInterface* configuration, std::string role,
-        unsigned int in_streams, unsigned int out_streams) :
-                config_(configuration), role_(role), in_streams_(in_streams),
-                out_streams_(out_streams)
+IshortToCshort::IshortToCshort(ConfigurationInterface* configuration, const std::string& role,
+    unsigned int in_streams, unsigned int out_streams) : config_(configuration), role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
     std::string default_input_item_type = "short";
     std::string default_output_item_type = "cshort";
@@ -51,6 +49,7 @@ IshortToCshort::IshortToCshort(ConfigurationInterface* configuration, std::strin
 
     dump_ = config_->property(role_ + ".dump", false);
     dump_filename_ = config_->property(role_ + ".dump_filename", default_dump_filename);
+    inverted_spectrum = configuration->property(role + ".inverted_spectrum", false);
 
     size_t item_size = sizeof(lv_16sc_t);
 
@@ -63,22 +62,48 @@ IshortToCshort::IshortToCshort(ConfigurationInterface* configuration, std::strin
             DLOG(INFO) << "Dumping output into file " << dump_filename_;
             file_sink_ = gr::blocks::file_sink::make(item_size, dump_filename_.c_str());
         }
+    if (inverted_spectrum)
+        {
+            conjugate_sc_ = make_conjugate_sc();
+        }
+    if (in_streams_ > 1)
+        {
+            LOG(ERROR) << "This implementation only supports one input stream";
+        }
+    if (out_streams_ > 1)
+        {
+            LOG(ERROR) << "This implementation only supports one output stream";
+        }
 }
 
 
-IshortToCshort::~IshortToCshort()
-{}
+IshortToCshort::~IshortToCshort() = default;
 
 
 void IshortToCshort::connect(gr::top_block_sptr top_block)
 {
     if (dump_)
         {
-            top_block->connect(interleaved_short_to_complex_short_, 0, file_sink_, 0);
+            if (inverted_spectrum)
+                {
+                    top_block->connect(interleaved_short_to_complex_short_, 0, conjugate_sc_, 0);
+                    top_block->connect(conjugate_sc_, 0, file_sink_, 0);
+                }
+            else
+                {
+                    top_block->connect(interleaved_short_to_complex_short_, 0, file_sink_, 0);
+                }
         }
     else
         {
-            DLOG(INFO) << "Nothing to connect internally";
+            if (inverted_spectrum)
+                {
+                    top_block->connect(interleaved_short_to_complex_short_, 0, conjugate_sc_, 0);
+                }
+            else
+                {
+                    DLOG(INFO) << "Nothing to connect internally";
+                }
         }
 }
 
@@ -87,22 +112,37 @@ void IshortToCshort::disconnect(gr::top_block_sptr top_block)
 {
     if (dump_)
         {
-            top_block->disconnect(interleaved_short_to_complex_short_, 0, file_sink_, 0);
+            if (inverted_spectrum)
+                {
+                    top_block->disconnect(interleaved_short_to_complex_short_, 0, conjugate_sc_, 0);
+                    top_block->disconnect(conjugate_sc_, 0, file_sink_, 0);
+                }
+            else
+                {
+                    top_block->disconnect(interleaved_short_to_complex_short_, 0, file_sink_, 0);
+                }
+        }
+    else
+        {
+            if (inverted_spectrum)
+                {
+                    top_block->disconnect(interleaved_short_to_complex_short_, 0, conjugate_sc_, 0);
+                }
         }
 }
 
 
-
 gr::basic_block_sptr IshortToCshort::get_left_block()
 {
     return interleaved_short_to_complex_short_;
 }
 
 
-
 gr::basic_block_sptr IshortToCshort::get_right_block()
 {
+    if (inverted_spectrum)
+        {
+            return conjugate_sc_;
+        }
     return interleaved_short_to_complex_short_;
 }
-
-
