@@ -5,7 +5,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -23,7 +23,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -40,11 +40,10 @@ interleaved_short_to_complex_short_sptr make_interleaved_short_to_complex_short(
 }
 
 
-
 interleaved_short_to_complex_short::interleaved_short_to_complex_short() : sync_decimator("interleaved_short_to_complex_short",
-                        gr::io_signature::make (1, 1, sizeof(int16_t)),
-                        gr::io_signature::make (1, 1, sizeof(lv_16sc_t)), // lv_16sc_t is a Volk's typedef for std::complex<short int>
-                        2)
+                                                                               gr::io_signature::make(1, 1, sizeof(int16_t)),
+                                                                               gr::io_signature::make(1, 1, sizeof(lv_16sc_t)),  // lv_16sc_t is a Volk's typedef for std::complex<short int>
+                                                                               2)
 {
     const int alignment_multiple = volk_get_alignment() / sizeof(lv_16sc_t);
     set_alignment(std::max(1, alignment_multiple));
@@ -52,15 +51,15 @@ interleaved_short_to_complex_short::interleaved_short_to_complex_short() : sync_
 
 
 int interleaved_short_to_complex_short::work(int noutput_items,
-        gr_vector_const_void_star &input_items,
-        gr_vector_void_star &output_items)
+    gr_vector_const_void_star &input_items,
+    gr_vector_void_star &output_items)
 {
-    const int16_t *in = (const int16_t *) input_items[0];
-    lv_16sc_t *out = (lv_16sc_t *) output_items[0];
+    const auto *in = reinterpret_cast<const int16_t *>(input_items[0]);
+    auto *out = reinterpret_cast<lv_16sc_t *>(output_items[0]);
     // This could be put into a Volk kernel
     int16_t real_part;
     int16_t imag_part;
-    for(int number = 0; number < noutput_items; number++)
+    for (int number = 0; number < noutput_items; number++)
         {
             // lv_cmake(r, i) defined at volk/volk_complex.h
             real_part = *in++;
