@@ -7,7 +7,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -25,45 +25,44 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
-#include <gps_l2c_signal.h>
-#include <cstdint>
-#include <cmath>
+#include "gps_l2c_signal.h"
 #include "GPS_L2C.h"
+#include <cmath>
 
 
 int32_t gps_l2c_m_shift(int32_t x)
 {
-    return static_cast<int32_t>((x >> 1)^((x & 1) * 0445112474));
+    return static_cast<int32_t>((x >> 1) ^ ((x & 1) * 0445112474));
 }
 
 
-void gps_l2c_m_code(int32_t * _dest, unsigned int _prn)
+void gps_l2c_m_code(int32_t* _dest, uint32_t _prn)
 {
     int32_t x;
-    x = GPS_L2C_M_INIT_REG[ _prn - 1];
-    for (int n = 0; n < GPS_L2_M_CODE_LENGTH_CHIPS; n++)
+    x = GPS_L2C_M_INIT_REG[_prn - 1];
+    for (int32_t n = 0; n < GPS_L2_M_CODE_LENGTH_CHIPS; n++)
         {
-            _dest[n] = (int8_t)(x&1);
+            _dest[n] = static_cast<int8_t>(x & 1);
             x = gps_l2c_m_shift(x);
         }
 }
 
 
-void gps_l2c_m_code_gen_complex(std::complex<float>* _dest, unsigned int _prn)
+void gps_l2c_m_code_gen_complex(std::complex<float>* _dest, uint32_t _prn)
 {
-    int32_t* _code = new int32_t[GPS_L2_M_CODE_LENGTH_CHIPS];
+    auto* _code = new int32_t[GPS_L2_M_CODE_LENGTH_CHIPS];
 
     if (_prn > 0 and _prn < 51)
         {
             gps_l2c_m_code(_code, _prn);
         }
 
-    for (signed int i = 0; i < GPS_L2_M_CODE_LENGTH_CHIPS; i++)
+    for (int32_t i = 0; i < GPS_L2_M_CODE_LENGTH_CHIPS; i++)
         {
             _dest[i] = std::complex<float>(1.0 - 2.0 * _code[i], 0.0);
         }
@@ -72,39 +71,57 @@ void gps_l2c_m_code_gen_complex(std::complex<float>* _dest, unsigned int _prn)
 }
 
 
+void gps_l2c_m_code_gen_float(float* _dest, uint32_t _prn)
+{
+    auto* _code = new int32_t[GPS_L2_M_CODE_LENGTH_CHIPS];
+
+    if (_prn > 0 and _prn < 51)
+        {
+            gps_l2c_m_code(_code, _prn);
+        }
+
+    for (int32_t i = 0; i < GPS_L2_M_CODE_LENGTH_CHIPS; i++)
+        {
+            _dest[i] = 1.0 - 2.0 * static_cast<float>(_code[i]);
+        }
+
+    delete[] _code;
+}
+
+
 /*
  *  Generates complex GPS L2C M code for the desired SV ID and sampled to specific sampling frequency
  */
-void gps_l2c_m_code_gen_complex_sampled(std::complex<float>* _dest, unsigned int _prn, signed int _fs)
+void gps_l2c_m_code_gen_complex_sampled(std::complex<float>* _dest, uint32_t _prn, int32_t _fs)
 {
-    int32_t* _code = new int32_t[GPS_L2_M_CODE_LENGTH_CHIPS];
+    auto* _code = new int32_t[GPS_L2_M_CODE_LENGTH_CHIPS];
     if (_prn > 0 and _prn < 51)
         {
             gps_l2c_m_code(_code, _prn);
         }
 
-    signed int _samplesPerCode, _codeValueIndex;
+    int32_t _samplesPerCode, _codeValueIndex;
     float _ts;
     float _tc;
-    const signed int _codeLength = GPS_L2_M_CODE_LENGTH_CHIPS;
+    const int32_t _codeLength = GPS_L2_M_CODE_LENGTH_CHIPS;
 
     //--- Find number of samples per spreading code ----------------------------
-    _samplesPerCode = static_cast<int>(static_cast<double>(_fs) / (static_cast<double>(GPS_L2_M_CODE_RATE_HZ) / static_cast<double>(_codeLength)));
+    _samplesPerCode = static_cast<int32_t>(static_cast<double>(_fs) / (static_cast<double>(GPS_L2_M_CODE_RATE_HZ) / static_cast<double>(_codeLength)));
 
     //--- Find time constants --------------------------------------------------
-    _ts = 1.0 / static_cast<float>(_fs);   // Sampling period in sec
+    _ts = 1.0 / static_cast<float>(_fs);                    // Sampling period in sec
     _tc = 1.0 / static_cast<float>(GPS_L2_M_CODE_RATE_HZ);  // C/A chip period in sec
 
     //float aux;
-    for (signed int i = 0; i < _samplesPerCode; i++)
+    for (int32_t i = 0; i < _samplesPerCode; i++)
         {
             //=== Digitizing =======================================================
 
             //--- Make index array to read L2C code values -------------------------
             //TODO: Check this formula! Seems to start with an extra sample
-            _codeValueIndex = ceil((_ts * ((float)i + 1)) / _tc) - 1;
+            _codeValueIndex = ceil((_ts * (static_cast<float>(i) + 1)) / _tc) - 1;
             //aux = (_ts * (i + 1)) / _tc;
-            //_codeValueIndex = static_cast<int>(static_cast<long>(aux)) - 1;
+            //_codeValueIndex = static_cast<int32_t>(static_cast<long>(aux)) - 1;
 
             //--- Make the digitized version of the L2C code -----------------------
             if (i == _samplesPerCode - 1)
@@ -114,12 +131,8 @@ void gps_l2c_m_code_gen_complex_sampled(std::complex<float>* _dest, unsigned int
                 }
             else
                 {
-                    _dest[i] = std::complex<float>(1.0 - 2.0 * _code[_codeValueIndex], 0); //repeat the chip -> upsample
+                    _dest[i] = std::complex<float>(1.0 - 2.0 * _code[_codeValueIndex], 0);  //repeat the chip -> upsample
                 }
         }
     delete[] _code;
 }
-
-
-
-
