@@ -9,7 +9,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -27,7 +27,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -69,11 +69,12 @@ static inline void volk_gnsssdr_64f_accumulator_64f_u_avx(double* result, const
     unsigned int i;
     const double* aPtr = inputBuffer;
 
-    __VOLK_ATTR_ALIGNED(32) double tempBuffer[4];
+    __VOLK_ATTR_ALIGNED(32)
+    double tempBuffer[4];
     __m256d accumulator = _mm256_setzero_pd();
     __m256d aVal = _mm256_setzero_pd();
 
-    for(number = 0; number < sse_iters; number++)
+    for (number = 0; number < sse_iters; number++)
         {
             aVal = _mm256_loadu_pd(aPtr);
             accumulator = _mm256_add_pd(accumulator, aVal);
@@ -82,12 +83,12 @@ static inline void volk_gnsssdr_64f_accumulator_64f_u_avx(double* result, const
 
     _mm256_storeu_pd((double*)tempBuffer, accumulator);
 
-    for(i = 0; i < 4; ++i)
+    for (i = 0; i < 4; ++i)
         {
             returnValue += tempBuffer[i];
         }
 
-    for(i = 0; i < (num_points % 4); ++i)
+    for (i = 0; i < (num_points % 4); ++i)
         {
             returnValue += (*aPtr++);
         }
@@ -100,7 +101,7 @@ static inline void volk_gnsssdr_64f_accumulator_64f_u_avx(double* result, const
 #ifdef LV_HAVE_SSE3
 #include <pmmintrin.h>
 
-static inline void volk_gnsssdr_64f_accumulator_64f_u_sse3(double* result,const double* inputBuffer, unsigned int num_points)
+static inline void volk_gnsssdr_64f_accumulator_64f_u_sse3(double* result, const double* inputBuffer, unsigned int num_points)
 {
     double returnValue = 0;
     const unsigned int sse_iters = num_points / 2;
@@ -108,11 +109,12 @@ static inline void volk_gnsssdr_64f_accumulator_64f_u_sse3(double* result,const
     unsigned int i;
     const double* aPtr = inputBuffer;
 
-    __VOLK_ATTR_ALIGNED(16) double tempBuffer[2];
+    __VOLK_ATTR_ALIGNED(16)
+    double tempBuffer[2];
     __m128d accumulator = _mm_setzero_pd();
     __m128d aVal = _mm_setzero_pd();
 
-    for(number = 0; number < sse_iters; number++)
+    for (number = 0; number < sse_iters; number++)
         {
             aVal = _mm_loadu_pd(aPtr);
             accumulator = _mm_add_pd(accumulator, aVal);
@@ -121,12 +123,12 @@ static inline void volk_gnsssdr_64f_accumulator_64f_u_sse3(double* result,const
 
     _mm_storeu_pd((double*)tempBuffer, accumulator);
 
-    for(i = 0; i < 2; ++i)
+    for (i = 0; i < 2; ++i)
         {
             returnValue += tempBuffer[i];
         }
 
-    for(i = 0; i < (num_points % 2); ++i)
+    for (i = 0; i < (num_points % 2); ++i)
         {
             returnValue += (*aPtr++);
         }
@@ -138,13 +140,13 @@ static inline void volk_gnsssdr_64f_accumulator_64f_u_sse3(double* result,const
 
 #ifdef LV_HAVE_GENERIC
 
-static inline void volk_gnsssdr_64f_accumulator_64f_generic(double* result,const double* inputBuffer, unsigned int num_points)
+static inline void volk_gnsssdr_64f_accumulator_64f_generic(double* result, const double* inputBuffer, unsigned int num_points)
 {
     const double* aPtr = inputBuffer;
     double returnValue = 0;
     unsigned int number;
 
-    for(number = 0; number < num_points; number++)
+    for (number = 0; number < num_points; number++)
         {
             returnValue += (*aPtr++);
         }
@@ -156,7 +158,7 @@ static inline void volk_gnsssdr_64f_accumulator_64f_generic(double* result,const
 #ifdef LV_HAVE_AVX
 #include <immintrin.h>
 
-static inline void volk_gnsssdr_64f_accumulator_64f_a_avx(double* result,const double* inputBuffer, unsigned int num_points)
+static inline void volk_gnsssdr_64f_accumulator_64f_a_avx(double* result, const double* inputBuffer, unsigned int num_points)
 {
     double returnValue = 0;
     const unsigned int sse_iters = num_points / 4;
@@ -164,11 +166,12 @@ static inline void volk_gnsssdr_64f_accumulator_64f_a_avx(double* result,const d
     unsigned int i;
     const double* aPtr = inputBuffer;
 
-    __VOLK_ATTR_ALIGNED(32) double tempBuffer[4];
+    __VOLK_ATTR_ALIGNED(32)
+    double tempBuffer[4];
     __m256d accumulator = _mm256_setzero_pd();
     __m256d aVal = _mm256_setzero_pd();
 
-    for(number = 0; number < sse_iters; number++)
+    for (number = 0; number < sse_iters; number++)
         {
             aVal = _mm256_load_pd(aPtr);
             accumulator = _mm256_add_pd(accumulator, aVal);
@@ -177,12 +180,12 @@ static inline void volk_gnsssdr_64f_accumulator_64f_a_avx(double* result,const d
 
     _mm256_store_pd((double*)tempBuffer, accumulator);
 
-    for(i = 0; i < 4; ++i)
+    for (i = 0; i < 4; ++i)
         {
             returnValue += tempBuffer[i];
         }
 
-    for(i = 0; i < (num_points % 4); ++i)
+    for (i = 0; i < (num_points % 4); ++i)
         {
             returnValue += (*aPtr++);
         }
@@ -195,7 +198,7 @@ static inline void volk_gnsssdr_64f_accumulator_64f_a_avx(double* result,const d
 #ifdef LV_HAVE_SSE3
 #include <pmmintrin.h>
 
-static inline void volk_gnsssdr_64f_accumulator_64f_a_sse3(double* result,const double* inputBuffer, unsigned int num_points)
+static inline void volk_gnsssdr_64f_accumulator_64f_a_sse3(double* result, const double* inputBuffer, unsigned int num_points)
 {
     double returnValue = 0;
     const unsigned int sse_iters = num_points / 2;
@@ -203,11 +206,12 @@ static inline void volk_gnsssdr_64f_accumulator_64f_a_sse3(double* result,const
     unsigned int i;
     const double* aPtr = inputBuffer;
 
-    __VOLK_ATTR_ALIGNED(16) double tempBuffer[2];
+    __VOLK_ATTR_ALIGNED(16)
+    double tempBuffer[2];
     __m128d accumulator = _mm_setzero_pd();
     __m128d aVal = _mm_setzero_pd();
 
-    for(number = 0; number < sse_iters; number++)
+    for (number = 0; number < sse_iters; number++)
         {
             aVal = _mm_load_pd(aPtr);
             accumulator = _mm_add_pd(accumulator, aVal);
@@ -216,12 +220,12 @@ static inline void volk_gnsssdr_64f_accumulator_64f_a_sse3(double* result,const
 
     _mm_store_pd((double*)tempBuffer, accumulator);
 
-    for(i = 0; i < 2; ++i)
+    for (i = 0; i < 2; ++i)
         {
             returnValue += tempBuffer[i];
         }
 
-    for(i = 0; i < (num_points % 2); ++i)
+    for (i = 0; i < (num_points % 2); ++i)
         {
             returnValue += (*aPtr++);
         }
