@@ -6,7 +6,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -24,26 +24,28 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
 
 #include "signal_generator.h"
-#include <glog/logging.h>
-#include "configuration_interface.h"
-#include "Galileo_E1.h"
+#include "GLONASS_L1_L2_CA.h"
 #include "GPS_L1_CA.h"
+#include "Galileo_E1.h"
 #include "Galileo_E5a.h"
+#include "configuration_interface.h"
+#include <glog/logging.h>
+#include <cstdint>
+#include <utility>
 
 
 using google::LogMessage;
 
 SignalGenerator::SignalGenerator(ConfigurationInterface* configuration,
-            std::string role, unsigned int in_stream,
-            unsigned int out_stream, boost::shared_ptr<gr::msg_queue> queue) :
-        role_(role), in_stream_(in_stream), out_stream_(out_stream), queue_(queue)
+    const std::string& role, unsigned int in_stream,
+    unsigned int out_stream, boost::shared_ptr<gr::msg_queue> queue) : role_(role), in_stream_(in_stream), out_stream_(out_stream), queue_(std::move(queue))
 {
     std::string default_item_type = "gr_complex";
     std::string default_dump_file = "./data/gen_source.dat";
@@ -84,31 +86,38 @@ SignalGenerator::SignalGenerator(ConfigurationInterface* configuration,
     // If there is only GPS signal (Galileo signal not present) -> vector duration = 1 ms
     unsigned int vector_length = 0;
     if (std::find(system.begin(), system.end(), "E") != system.end())
-    {
-	if (signal1[0].at(0)=='5')
-	    {
-		vector_length = round((float) fs_in / (Galileo_E5a_CODE_CHIP_RATE_HZ
-			/ Galileo_E5a_CODE_LENGTH_CHIPS));
-	    }
-	else
-	    {
-		vector_length = round((float)fs_in / (Galileo_E1_CODE_CHIP_RATE_HZ
-			/ Galileo_E1_B_CODE_LENGTH_CHIPS))
-                                	  * Galileo_E1_C_SECONDARY_CODE_LENGTH;
-	    }
-    }
+        {
+            if (signal1[0].at(0) == '5')
+                {
+                    vector_length = round(static_cast<float>(fs_in) / (Galileo_E5a_CODE_CHIP_RATE_HZ / Galileo_E5a_CODE_LENGTH_CHIPS));
+                }
+            else
+                {
+                    vector_length = round(static_cast<float>(fs_in) / (Galileo_E1_CODE_CHIP_RATE_HZ / Galileo_E1_B_CODE_LENGTH_CHIPS)) * Galileo_E1_C_SECONDARY_CODE_LENGTH;
+                }
+        }
     else if (std::find(system.begin(), system.end(), "G") != system.end())
-    {
-        vector_length = round((float)fs_in
-                 / (GPS_L1_CA_CODE_RATE_HZ / GPS_L1_CA_CODE_LENGTH_CHIPS));
-    }
+        {
+            vector_length = round(static_cast<float>(fs_in) / (GPS_L1_CA_CODE_RATE_HZ / GPS_L1_CA_CODE_LENGTH_CHIPS));
+        }
+    else if (std::find(system.begin(), system.end(), "R") != system.end())
+        {
+            if (signal1[0].at(0) == '1')
+                {
+                    vector_length = round(static_cast<float>(fs_in) / (GLONASS_L1_CA_CODE_RATE_HZ / GLONASS_L1_CA_CODE_LENGTH_CHIPS));
+                }
+            else
+                {
+                    vector_length = round(static_cast<float>(fs_in) / (GLONASS_L2_CA_CODE_RATE_HZ / GLONASS_L2_CA_CODE_LENGTH_CHIPS));
+                }
+        }
 
-    if (item_type_.compare("gr_complex") == 0)
+    if (item_type_ == "gr_complex")
         {
             item_size_ = sizeof(gr_complex);
             DLOG(INFO) << "Item size " << item_size_;
             gen_source_ = signal_make_generator_c(signal1, system, PRN, CN0_dB, doppler_Hz, delay_chips, delay_sec,
-                                             data_flag, noise_flag, fs_in, vector_length, BW_BB);
+                data_flag, noise_flag, fs_in, vector_length, BW_BB);
 
             vector_to_stream_ = gr::blocks::vector_to_stream::make(item_size_, vector_length);
 
@@ -119,7 +128,7 @@ SignalGenerator::SignalGenerator(ConfigurationInterface* configuration,
     else
         {
             LOG(WARNING) << item_type_ << " unrecognized item type for resampler";
-            item_size_ = sizeof(short);
+            item_size_ = sizeof(int16_t);
         }
 
     if (dump_)
@@ -131,39 +140,45 @@ SignalGenerator::SignalGenerator(ConfigurationInterface* configuration,
         {
             DLOG(INFO) << "file_sink(" << file_sink_->unique_id() << ")";
         }
+    if (in_stream_ > 0)
+        {
+            LOG(ERROR) << "A signal source does not have an input stream";
+        }
+    if (out_stream_ > 1)
+        {
+            LOG(ERROR) << "This implementation only supports one output stream";
+        }
 }
 
 
-SignalGenerator::~SignalGenerator()
-{}
+SignalGenerator::~SignalGenerator() = default;
 
 
 void SignalGenerator::connect(gr::top_block_sptr top_block)
 {
-    if (item_type_.compare("gr_complex") == 0)
+    if (item_type_ == "gr_complex")
         {
             top_block->connect(gen_source_, 0, vector_to_stream_, 0);
             DLOG(INFO) << "connected gen_source to vector_to_stream";
 
             if (dump_)
-            {
-                top_block->connect(vector_to_stream_, 0, file_sink_, 0);
-                DLOG(INFO) << "connected vector_to_stream_ to file sink";
-            }
-
+                {
+                    top_block->connect(vector_to_stream_, 0, file_sink_, 0);
+                    DLOG(INFO) << "connected vector_to_stream_ to file sink";
+                }
         }
 }
 
 
 void SignalGenerator::disconnect(gr::top_block_sptr top_block)
 {
-    if (item_type_.compare("gr_complex") == 0)
+    if (item_type_ == "gr_complex")
         {
             top_block->disconnect(gen_source_, 0, vector_to_stream_, 0);
             if (dump_)
-            {
-                top_block->disconnect(vector_to_stream_, 0, file_sink_, 0);
-            }
+                {
+                    top_block->disconnect(vector_to_stream_, 0, file_sink_, 0);
+                }
         }
 }
 
