@@ -5,7 +5,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -23,7 +23,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -31,12 +31,14 @@
 #ifndef GNSS_SDR_SIGNAL_GENERATOR_C_H
 #define GNSS_SDR_SIGNAL_GENERATOR_C_H
 
+#include "gnss_signal.h"
+#include <boost/scoped_array.hpp>
+//#include <gnuradio/random.h>
+#include <gnuradio/block.h>
+#include <random>
 #include <string>
 #include <vector>
-#include <boost/scoped_array.hpp>
-#include <gnuradio/random.h>
-#include <gnuradio/block.h>
-#include "gnss_signal.h"
+
 
 class signal_generator_c;
 
@@ -60,10 +62,10 @@ typedef boost::shared_ptr<signal_generator_c> signal_generator_c_sptr;
 * interface for creating new instances.
 */
 signal_generator_c_sptr
-signal_make_generator_c (std::vector<std::string> signal1, std::vector<std::string> system, const std::vector<unsigned int> &PRN,
-                    const std::vector<float> &CN0_dB, const std::vector<float> &doppler_Hz,
-                    const std::vector<unsigned int> &delay_chips,const std::vector<unsigned int> &delay_sec, bool data_flag, bool noise_flag,
-                    unsigned int fs_in, unsigned int vector_length, float BW_BB);
+signal_make_generator_c(std::vector<std::string> signal1, std::vector<std::string> system, const std::vector<unsigned int> &PRN,
+    const std::vector<float> &CN0_dB, const std::vector<float> &doppler_Hz,
+    const std::vector<unsigned int> &delay_chips, const std::vector<unsigned int> &delay_sec, bool data_flag, bool noise_flag,
+    unsigned int fs_in, unsigned int vector_length, float BW_BB);
 
 /*!
 * \brief This class generates synthesized GNSS signal.
@@ -79,15 +81,15 @@ private:
 
     /* Create the signal_generator_c object*/
     friend signal_generator_c_sptr
-    signal_make_generator_c (std::vector<std::string> signal1, std::vector<std::string> system, const std::vector<unsigned int> &PRN,
-            const std::vector<float> &CN0_dB, const std::vector<float> &doppler_Hz,
-            const std::vector<unsigned int> &delay_chips,const std::vector<unsigned int> &delay_sec, bool data_flag, bool noise_flag,
-            unsigned int fs_in, unsigned int vector_length, float BW_BB);
+    signal_make_generator_c(std::vector<std::string> signal1, std::vector<std::string> system, const std::vector<unsigned int> &PRN,
+        const std::vector<float> &CN0_dB, const std::vector<float> &doppler_Hz,
+        const std::vector<unsigned int> &delay_chips, const std::vector<unsigned int> &delay_sec, bool data_flag, bool noise_flag,
+        unsigned int fs_in, unsigned int vector_length, float BW_BB);
 
-    signal_generator_c (std::vector<std::string> signal1, std::vector<std::string> system, const std::vector<unsigned int> &PRN,
-            const std::vector<float> &CN0_dB, const std::vector<float> &doppler_Hz,
-            const std::vector<unsigned int> &delay_chips,const std::vector<unsigned int> &delay_sec, bool data_flag, bool noise_flag,
-            unsigned int fs_in, unsigned int vector_length, float BW_BB);
+    signal_generator_c(std::vector<std::string> signal1, std::vector<std::string> system, const std::vector<unsigned int> &PRN,
+        std::vector<float> CN0_dB, std::vector<float> doppler_Hz,
+        std::vector<unsigned int> delay_chips, std::vector<unsigned int> delay_sec, bool data_flag, bool noise_flag,
+        unsigned int fs_in, unsigned int vector_length, float BW_BB);
 
     void init();
     void generate_codes();
@@ -116,23 +118,27 @@ private:
     std::vector<signed int> data_modulation_;
     std::vector<signed int> pilot_modulation_;
 
-    boost::scoped_array<gr_complex*> sampled_code_data_;
-    boost::scoped_array<gr_complex*> sampled_code_pilot_;
-    gr::random* random_;
-    gr_complex* complex_phase_;
+    boost::scoped_array<gr_complex *> sampled_code_data_;
+    boost::scoped_array<gr_complex *> sampled_code_pilot_;
+    //gr::random *random_;
+    gr_complex *complex_phase_;
 
     unsigned int work_counter_;
+    std::random_device r;
+    std::default_random_engine e1;
+    std::default_random_engine e2;
+    std::uniform_int_distribution<int> uniform_dist;
+    std::normal_distribution<float> normal_dist;
 
 public:
-    ~signal_generator_c();    // public destructor
+    ~signal_generator_c();  // public destructor
 
     // Where all the action really happens
 
-    int general_work (int noutput_items,
-            gr_vector_int &ninput_items,
-            gr_vector_const_void_star &input_items,
-            gr_vector_void_star &output_items);
+    int general_work(int noutput_items,
+        gr_vector_int &ninput_items,
+        gr_vector_const_void_star &input_items,
+        gr_vector_void_star &output_items);
 };
 
 #endif /* GNSS_SDR_SIGNAL_GENERATOR_C_H */
-
