@@ -7,11 +7,11 @@
  * Code DLL + carrier PLL according to the algorithms described in:
  * K.Borre, D.M.Akos, N.Bertelsen, P.Rinder, and S.H.Jensen,
  * A Software-Defined GPS and Galileo Receiver. A Single-Frequency
- * Approach, Birkha user, 2007
+ * Approach, Birkhauser, 2007
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -29,7 +29,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -37,10 +37,9 @@
 #ifndef GNSS_SDR_GALILEO_E1_DLL_PLL_VEML_TRACKING_H_
 #define GNSS_SDR_GALILEO_E1_DLL_PLL_VEML_TRACKING_H_
 
-
-#include <string>
+#include "dll_pll_veml_tracking.h"
 #include "tracking_interface.h"
-#include "galileo_e1_dll_pll_veml_tracking_cc.h"
+#include <string>
 
 
 class ConfigurationInterface;
@@ -53,50 +52,53 @@ class GalileoE1DllPllVemlTracking : public TrackingInterface
 {
 public:
     GalileoE1DllPllVemlTracking(ConfigurationInterface* configuration,
-            std::string role,
-            unsigned int in_streams,
-            unsigned int out_streams);
+        const std::string& role,
+        unsigned int in_streams,
+        unsigned int out_streams);
 
     virtual ~GalileoE1DllPllVemlTracking();
 
-    std::string role()
+    inline std::string role() override
     {
         return role_;
     }
 
     //! Returns "Galileo_E1_DLL_PLL_VEML_Tracking"
-    std::string implementation()
+    inline std::string implementation() override
     {
         return "Galileo_E1_DLL_PLL_VEML_Tracking";
     }
-    size_t item_size()
+
+    inline size_t item_size() override
     {
         return item_size_;
     }
 
-    void connect(gr::top_block_sptr top_block);
-    void disconnect(gr::top_block_sptr top_block);
-    gr::basic_block_sptr get_left_block();
-    gr::basic_block_sptr get_right_block();
-
+    void connect(gr::top_block_sptr top_block) override;
+    void disconnect(gr::top_block_sptr top_block) override;
+    gr::basic_block_sptr get_left_block() override;
+    gr::basic_block_sptr get_right_block() override;
 
     /*!
      * \brief Set tracking channel unique ID
      */
-    void set_channel(unsigned int channel);
+    void set_channel(unsigned int channel) override;
 
     /*!
      * \brief Set acquisition/tracking common Gnss_Synchro object pointer
      * to efficiently exchange synchronization data between acquisition and
      *  tracking blocks
      */
-    void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro);
+    void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro) override;
 
-
-    void start_tracking();
+    void start_tracking() override;
+    /*!
+     * \brief Stop running tracking
+     */
+    void stop_tracking() override;
 
 private:
-    galileo_e1_dll_pll_veml_tracking_cc_sptr tracking_;
+    dll_pll_veml_tracking_sptr tracking_;
     size_t item_size_;
     unsigned int channel_;
     std::string role_;
@@ -104,4 +106,4 @@ private:
     unsigned int out_streams_;
 };
 
-#endif // GNSS_SDR_GALILEO_E1_DLL_PLL_VEML_TRACKING_H_
+#endif  // GNSS_SDR_GALILEO_E1_DLL_PLL_VEML_TRACKING_H_
