@@ -13,7 +13,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2012-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2012-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -31,7 +31,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -39,9 +39,9 @@
 #ifndef GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H_
 #define GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H_
 
-#include <string>
-#include "tracking_interface.h"
 #include "galileo_e1_tcp_connector_tracking_cc.h"
+#include "tracking_interface.h"
+#include <string>
 
 
 class ConfigurationInterface;
@@ -53,47 +53,50 @@ class GalileoE1TcpConnectorTracking : public TrackingInterface
 {
 public:
     GalileoE1TcpConnectorTracking(ConfigurationInterface* configuration,
-            std::string role,
-            unsigned int in_streams,
-            unsigned int out_streams);
+        const std::string& role,
+        unsigned int in_streams,
+        unsigned int out_streams);
 
     virtual ~GalileoE1TcpConnectorTracking();
 
-    std::string role()
+    inline std::string role() override
     {
         return role_;
     }
 
     //! Returns "Galileo_E1_TCP_CONNECTOR_Tracking"
-    std::string implementation()
+    inline std::string implementation() override
     {
         return "Galileo_E1_TCP_CONNECTOR_Tracking";
     }
-    size_t item_size()
+
+    inline size_t item_size() override
     {
         return item_size_;
     }
 
-    void connect(gr::top_block_sptr top_block);
-    void disconnect(gr::top_block_sptr top_block);
-    gr::basic_block_sptr get_left_block();
-    gr::basic_block_sptr get_right_block();
-
+    void connect(gr::top_block_sptr top_block) override;
+    void disconnect(gr::top_block_sptr top_block) override;
+    gr::basic_block_sptr get_left_block() override;
+    gr::basic_block_sptr get_right_block() override;
 
     /*!
      * \brief Set tracking channel unique ID
      */
-    void set_channel(unsigned int channel);
+    void set_channel(unsigned int channel) override;
 
     /*!
      * \brief Set acquisition/tracking common Gnss_Synchro object pointer
      * to efficiently exchange synchronization data between acquisition and
      *  tracking blocks
      */
-    void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro);
+    void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro) override;
 
-
-    void start_tracking();
+    void start_tracking() override;
+    /*!
+     * \brief Stop running tracking
+     */
+    void stop_tracking() override;
 
 private:
     galileo_e1_tcp_connector_tracking_cc_sptr tracking_;
@@ -104,4 +107,4 @@ private:
     unsigned int out_streams_;
 };
 
-#endif // GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H_
+#endif  // GNSS_SDR_GALILEO_E1_TCP_CONNECTOR_TRACKING_H_
