@@ -10,7 +10,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -28,7 +28,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -36,91 +36,90 @@
 #ifndef GNSS_SDR_GPS_L1_CA_DLL_PLL_TRACKING_GPU_CC_H
 #define GNSS_SDR_GPS_L1_CA_DLL_PLL_TRACKING_GPU_CC_H
 
-#include <fstream>
-#include <map>
-#include <string>
-#include <gnuradio/block.h>
+#include "cuda_multicorrelator.h"
 #include "gnss_synchro.h"
 #include "tracking_2nd_DLL_filter.h"
 #include "tracking_FLL_PLL_filter.h"
-#include "cuda_multicorrelator.h"
+#include <gnuradio/block.h>
+#include <fstream>
+#include <map>
+#include <string>
+
 
 class Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc;
 
 typedef boost::shared_ptr<Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc>
-        gps_l1_ca_dll_pll_tracking_gpu_cc_sptr;
+    gps_l1_ca_dll_pll_tracking_gpu_cc_sptr;
 
 gps_l1_ca_dll_pll_tracking_gpu_cc_sptr
-gps_l1_ca_dll_pll_make_tracking_gpu_cc(long if_freq,
-                                   long fs_in, 
-                                   unsigned int vector_length,
-                                   bool dump,
-                                   std::string dump_filename,
-                                   float pll_bw_hz,
-                                   float dll_bw_hz,
-                                   float early_late_space_chips);
-
+gps_l1_ca_dll_pll_make_tracking_gpu_cc(
+    int64_t fs_in,
+    uint32_t vector_length,
+    bool dump,
+    std::string dump_filename,
+    float pll_bw_hz,
+    float dll_bw_hz,
+    float early_late_space_chips);
 
 
 /*!
  * \brief This class implements a DLL + PLL tracking loop block
  */
-class Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc: public gr::block
+class Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc : public gr::block
 {
 public:
     ~Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc();
 
-    void set_channel(unsigned int channel);
-    void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro);
+    void set_channel(uint32_t channel);
+    void set_gnss_synchro(Gnss_Synchro *p_gnss_synchro);
     void start_tracking();
 
-    int general_work (int noutput_items, gr_vector_int &ninput_items,
-            gr_vector_const_void_star &input_items, gr_vector_void_star &output_items);
+    int general_work(int noutput_items, gr_vector_int &ninput_items,
+        gr_vector_const_void_star &input_items, gr_vector_void_star &output_items);
 
-    void forecast (int noutput_items, gr_vector_int &ninput_items_required);
+    void forecast(int noutput_items, gr_vector_int &ninput_items_required);
 
 private:
     friend gps_l1_ca_dll_pll_tracking_gpu_cc_sptr
-    gps_l1_ca_dll_pll_make_tracking_gpu_cc(long if_freq,
-            long fs_in,
-            unsigned int vector_length,
-            bool dump,
-            std::string dump_filename,
-            float pll_bw_hz,
-            float dll_bw_hz,
-            float early_late_space_chips);
+    gps_l1_ca_dll_pll_make_tracking_gpu_cc(
+        int64_t fs_in,
+        uint32_t vector_length,
+        bool dump,
+        std::string dump_filename,
+        float pll_bw_hz,
+        float dll_bw_hz,
+        float early_late_space_chips);
 
-    Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc(long if_freq,
-            long fs_in, 
-            unsigned int vector_length,
-            bool dump,
-            std::string dump_filename,
-            float pll_bw_hz,
-            float dll_bw_hz,
-            float early_late_space_chips);
+    Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc(
+        int64_t fs_in,
+        uint32_t vector_length,
+        bool dump,
+        std::string dump_filename,
+        float pll_bw_hz,
+        float dll_bw_hz,
+        float early_late_space_chips);
     void update_local_code();
     void update_local_carrier();
 
     // tracking configuration vars
-    unsigned int d_vector_length;
+    uint32_t d_vector_length;
     bool d_dump;
 
-    Gnss_Synchro* d_acquisition_gnss_synchro;
-    unsigned int d_channel;
+    Gnss_Synchro *d_acquisition_gnss_synchro;
+    uint32_t d_channel;
 
-    long d_if_freq;
-    long d_fs_in;
+    int64_t d_if_freq;
+    int64_t d_fs_in;
 
     double d_early_late_spc_chips;
-    int d_n_correlator_taps;
-
+    int32_t d_n_correlator_taps;
 
     //GPU HOST PINNED MEMORY IN/OUT VECTORS
-    gr_complex* in_gpu;
-    float* d_local_code_shift_chips;
-    gr_complex* d_correlator_outs;
+    gr_complex *in_gpu;
+    float *d_local_code_shift_chips;
+    gr_complex *d_correlator_outs;
     cuda_multicorrelator *multicorrelator_gpu;
-    gr_complex* d_ca_code;
+    gr_complex *d_ca_code;
 
     gr_complex *d_Early;
     gr_complex *d_Prompt;
@@ -150,19 +149,19 @@ private:
     double d_pll_to_dll_assist_secs_Ti;
 
     //Integration period in samples
-    int d_correlation_length_samples;
+    int32_t d_correlation_length_samples;
 
     //processing samples counters
-    unsigned long int d_sample_counter;
-    unsigned long int d_acq_sample_stamp;
+    uint64_t d_sample_counter;
+    uint64_t d_acq_sample_stamp;
 
     // CN0 estimation and lock detector
-    int d_cn0_estimation_counter;
-    gr_complex* d_Prompt_buffer;
+    int32_t d_cn0_estimation_counter;
+    gr_complex *d_Prompt_buffer;
     double d_carrier_lock_test;
     double d_CN0_SNV_dB_Hz;
     double d_carrier_lock_threshold;
-    int d_carrier_lock_fail_counter;
+    int32_t d_carrier_lock_fail_counter;
 
     // control vars
     bool d_enable_tracking;
@@ -176,4 +175,4 @@ private:
     std::string sys;
 };
 
-#endif //GNSS_SDR_GPS_L1_CA_DLL_PLL_TRACKING_GPU_CC_H
+#endif  //GNSS_SDR_GPS_L1_CA_DLL_PLL_TRACKING_GPU_CC_H
