@@ -12,7 +12,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -30,7 +30,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -41,7 +41,8 @@
 #include "gnss_block_interface.h"
 #include "gnss_synchro.h"
 
-template<typename Data>class concurrent_queue;
+template <typename Data>
+class concurrent_queue;
 
 /*! \brief This abstract class represents an interface to an acquisition GNSS block.
  *
@@ -50,10 +51,9 @@ template<typename Data>class concurrent_queue;
  * instantiated directly if all inherited pure virtual methods have been
  * implemented by that class or a parent class.
  */
-class AcquisitionInterface: public GNSSBlockInterface
+class AcquisitionInterface : public GNSSBlockInterface
 {
 public:
-    //virtual void set_active(bool active) = 0;
     virtual void set_gnss_synchro(Gnss_Synchro* gnss_synchro) = 0;
     virtual void set_channel(unsigned int channel) = 0;
     virtual void set_threshold(float threshold) = 0;
@@ -61,8 +61,11 @@ public:
     virtual void set_doppler_step(unsigned int doppler_step) = 0;
     virtual void init() = 0;
     virtual void set_local_code() = 0;
+    virtual void set_state(int state) = 0;
     virtual signed int mag() = 0;
     virtual void reset() = 0;
+    virtual void stop_acquisition() = 0;
+    virtual void set_resampler_latency(uint32_t latency_samples) = 0;
 };
 
 #endif /* GNSS_SDR_ACQUISITION_INTERFACE */
