@@ -3,7 +3,9 @@
  * Redistribution and modifications are permitted subject to BSD license.
  */
 #define	_POSIX_PTHREAD_SEMANTICS	/* for Sun */
+#ifndef _REENTRANT
 #define	_REENTRANT			/* for Sun */
+#endif
 #include <asn_internal.h>
 #include <GeneralizedTime.h>
 #include <errno.h>
@@ -367,7 +369,7 @@ asn_GT2time_frac(const GeneralizedTime_t *st, int *frac_value, int *frac_digits,
 			errno = EINVAL;				\
 			return -1;				\
 		} else {					\
-			var = var * 10 + (ch - 0x30);		\
+			(var) = (var) * 10 + (ch - 0x30);		\
 			buf++;					\
 		}						\
 	} while(0)
