@@ -9,7 +9,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -27,17 +27,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
 
-
 #ifndef GNSS_SDR_FILE_CONFIGURATION_H_
 #define GNSS_SDR_FILE_CONFIGURATION_H_
 
 #include "configuration_interface.h"
+#include <cstdint>
 #include <memory>
 #include <string>
 
@@ -60,16 +60,19 @@ public:
     FileConfiguration(std::string filename);
     FileConfiguration();
     //! Virtual destructor
-     ~FileConfiguration();
+    ~FileConfiguration();
     std::string property(std::string property_name, std::string default_value);
     bool property(std::string property_name, bool default_value);
-    long property(std::string property_name, long default_value);
-    int property(std::string property_name, int default_value);
-    unsigned int property(std::string property_name, unsigned int default_value);
-    unsigned short property(std::string property_name, unsigned short default_value);
+    int64_t property(std::string property_name, int64_t default_value);
+    uint64_t property(std::string property_name, uint64_t default_value);
+    int32_t property(std::string property_name, int32_t default_value);
+    uint32_t property(std::string property_name, uint32_t default_value);
+    int16_t property(std::string property_name, int16_t default_value);
+    uint16_t property(std::string property_name, uint16_t default_value);
     float property(std::string property_name, float default_value);
     double property(std::string property_name, double default_value);
     void set_property(std::string property_name, std::string value);
+
 private:
     void init();
     std::string filename_;
