@@ -11,7 +11,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -29,7 +29,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -37,10 +37,11 @@
 #ifndef GNSS_SDR_BLOCK_FACTORY_H_
 #define GNSS_SDR_BLOCK_FACTORY_H_
 
+#include <gnuradio/msg_queue.h>
 #include <memory>
 #include <string>
 #include <vector>
-#include <gnuradio/msg_queue.h>
+
 
 class ConfigurationInterface;
 class GNSSBlockInterface;
@@ -57,7 +58,7 @@ public:
     GNSSBlockFactory();
     virtual ~GNSSBlockFactory();
     std::unique_ptr<GNSSBlockInterface> GetSignalSource(std::shared_ptr<ConfigurationInterface> configuration,
-            boost::shared_ptr<gr::msg_queue> queue, int ID = -1);
+        gr::msg_queue::sptr queue, int ID = -1);
 
     std::unique_ptr<GNSSBlockInterface> GetSignalConditioner(std::shared_ptr<ConfigurationInterface> configuration, int ID = -1);
 
@@ -66,52 +67,62 @@ public:
     std::unique_ptr<GNSSBlockInterface> GetObservables(std::shared_ptr<ConfigurationInterface> configuration);
 
     std::unique_ptr<std::vector<std::unique_ptr<GNSSBlockInterface>>> GetChannels(std::shared_ptr<ConfigurationInterface> configuration,
-            boost::shared_ptr<gr::msg_queue> queue);
+        gr::msg_queue::sptr queue);
 
     /*
      * \brief Returns the block with the required configuration and implementation
      */
     std::unique_ptr<GNSSBlockInterface> GetBlock(std::shared_ptr<ConfigurationInterface> configuration,
-            std::string role, std::string implementation,
-            unsigned int in_streams, unsigned int out_streams,
-            boost::shared_ptr<gr::msg_queue> queue = nullptr);
+        std::string role, std::string implementation,
+        unsigned int in_streams, unsigned int out_streams,
+        gr::msg_queue::sptr queue = nullptr);
 
 private:
-
     std::unique_ptr<GNSSBlockInterface> GetChannel_1C(std::shared_ptr<ConfigurationInterface> configuration,
-            std::string acq, std::string trk, std::string tlm, int channel,
-            boost::shared_ptr<gr::msg_queue> queue);
+        std::string acq, std::string trk, std::string tlm, int channel,
+        gr::msg_queue::sptr queue);
 
     std::unique_ptr<GNSSBlockInterface> GetChannel_2S(std::shared_ptr<ConfigurationInterface> configuration,
-            std::string acq, std::string trk, std::string tlm, int channel,
-            boost::shared_ptr<gr::msg_queue> queue);
+        std::string acq, std::string trk, std::string tlm, int channel,
+        gr::msg_queue::sptr queue);
 
     std::unique_ptr<GNSSBlockInterface> GetChannel_1B(std::shared_ptr<ConfigurationInterface> configuration,
-            std::string acq, std::string trk, std::string tlm, int channel,
-            boost::shared_ptr<gr::msg_queue> queue);
+        std::string acq, std::string trk, std::string tlm, int channel,
+        gr::msg_queue::sptr queue);
 
     std::unique_ptr<GNSSBlockInterface> GetChannel_5X(std::shared_ptr<ConfigurationInterface> configuration,
-            std::string acq, std::string trk, std::string tlm, int channel,
-            boost::shared_ptr<gr::msg_queue> queue);
+        std::string acq, std::string trk, std::string tlm, int channel,
+        gr::msg_queue::sptr queue);
+
+    std::unique_ptr<GNSSBlockInterface> GetChannel_L5(std::shared_ptr<ConfigurationInterface> configuration,
+        std::string acq, std::string trk, std::string tlm, int channel,
+        gr::msg_queue::sptr queue);
+
+    std::unique_ptr<GNSSBlockInterface> GetChannel_1G(std::shared_ptr<ConfigurationInterface> configuration,
+        std::string acq, std::string trk, std::string tlm, int channel,
+        boost::shared_ptr<gr::msg_queue> queue);
+
+    std::unique_ptr<GNSSBlockInterface> GetChannel_2G(std::shared_ptr<ConfigurationInterface> configuration,
+        std::string acq, std::string trk, std::string tlm, int channel,
+        boost::shared_ptr<gr::msg_queue> queue);
 
     std::unique_ptr<AcquisitionInterface> GetAcqBlock(
-            std::shared_ptr<ConfigurationInterface> configuration,
-            std::string role,
-            std::string implementation, unsigned int in_streams,
-            unsigned int out_streams);
+        std::shared_ptr<ConfigurationInterface> configuration,
+        std::string role,
+        std::string implementation, unsigned int in_streams,
+        unsigned int out_streams);
 
     std::unique_ptr<TrackingInterface> GetTrkBlock(
-            std::shared_ptr<ConfigurationInterface> configuration,
-            std::string role,
-            std::string implementation, unsigned int in_streams,
-            unsigned int out_streams);
+        std::shared_ptr<ConfigurationInterface> configuration,
+        std::string role,
+        std::string implementation, unsigned int in_streams,
+        unsigned int out_streams);
 
     std::unique_ptr<TelemetryDecoderInterface> GetTlmBlock(
-            std::shared_ptr<ConfigurationInterface> configuration,
-            std::string role,
-            std::string implementation, unsigned int in_streams,
-            unsigned int out_streams);
+        std::shared_ptr<ConfigurationInterface> configuration,
+        std::string role,
+        std::string implementation, unsigned int in_streams,
+        unsigned int out_streams);
 };
 
 #endif /*GNSS_SDR_BLOCK_FACTORY_H_*/
-
