@@ -6,7 +6,7 @@
  *  Javier Arribas, 2012. jarribas(at)cttc.es
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -24,7 +24,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -46,15 +46,16 @@ class Gnss_Signal
 private:
     Gnss_Satellite satellite;
     std::string signal;
+
 public:
     Gnss_Signal();
     Gnss_Signal(const std::string& signal_);
     Gnss_Signal(const Gnss_Satellite& satellite_, const std::string& signal_);
     ~Gnss_Signal();
-    std::string get_signal_str() const; //!<  Get the satellite signal {"1C" for GPS L1 C/A, "2S" for GPS L2C (M), "1B" for Galileo E1B, "5X" for Galileo E5a}
-    Gnss_Satellite get_satellite() const;    //!< Get the Gnss_Satellite associated to the signal
-    friend bool operator== (const Gnss_Signal &, const Gnss_Signal &);    //!< operator== for comparison
-    friend std::ostream& operator<<(std::ostream &, const Gnss_Signal &); //!< operator<< for pretty printing
+    std::string get_signal_str() const;                                  //!< Get the satellite signal {"1C" for GPS L1 C/A, "2S" for GPS L2C (M), "L5" for GPS L5, "1G" for GLONASS L1 C/A, "1B" for Galileo E1B, "5X" for Galileo E5a.
+    Gnss_Satellite get_satellite() const;                                //!< Get the Gnss_Satellite associated to the signal
+    friend bool operator==(const Gnss_Signal&, const Gnss_Signal&);      //!< operator== for comparison
+    friend std::ostream& operator<<(std::ostream&, const Gnss_Signal&);  //!< operator<< for pretty printing
 };
 
 #endif
