@@ -7,7 +7,7 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
@@ -25,37 +25,37 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+ * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
 #include "gps_ephemeris.h"
-#include <cmath>
 #include "GPS_L1_CA.h"
 #include "gnss_satellite.h"
+#include <cmath>
 
 Gps_Ephemeris::Gps_Ephemeris()
 {
-    i_satellite_PRN = 0;
+    i_satellite_PRN = 0U;
     d_TOW = 0;
-    d_Crs = 0;
-    d_Delta_n = 0;
-    d_M_0 = 0;
-    d_Cuc = 0;
-    d_e_eccentricity = 0;
-    d_Cus = 0;
-    d_sqrt_A = 0;
+    d_Crs = 0.0;
+    d_Delta_n = 0.0;
+    d_M_0 = 0.0;
+    d_Cuc = 0.0;
+    d_e_eccentricity = 0.0;
+    d_Cus = 0.0;
+    d_sqrt_A = 0.0;
     d_Toe = 0;
     d_Toc = 0;
-    d_Cic = 0;
-    d_OMEGA0 = 0;
-    d_Cis = 0;
-    d_i_0 = 0;
-    d_Crc = 0;
-    d_OMEGA = 0;
-    d_OMEGA_DOT = 0;
-    d_IDOT = 0;
+    d_Cic = 0.0;
+    d_OMEGA0 = 0.0;
+    d_Cis = 0.0;
+    d_i_0 = 0.0;
+    d_Crc = 0.0;
+    d_OMEGA = 0.0;
+    d_OMEGA_DOT = 0.0;
+    d_IDOT = 0.0;
     i_code_on_L2 = 0;
     i_GPS_week = 0;
     b_L2_P_data_flag = false;
@@ -63,25 +63,25 @@ Gps_Ephemeris::Gps_Ephemeris()
     i_SV_health = 0;
     d_IODE_SF2 = 0;
     d_IODE_SF3 = 0;
-    d_TGD = 0;            // Estimated Group Delay Differential: L1-L2 correction term only for the benefit of "L1 P(Y)" or "L2 P(Y)" s users [s]
-    d_IODC = 0;           // Issue of Data, Clock
-    i_AODO = 0;           // Age of Data Offset (AODO) term for the navigation message correction table (NMCT) contained in subframe 4 (reference paragraph 20.3.3.5.1.9) [s]
+    d_TGD = 0.0;  // Estimated Group Delay Differential: L1-L2 correction term only for the benefit of "L1 P(Y)" or "L2 P(Y)" s users [s]
+    d_IODC = 0;   // Issue of Data, Clock
+    i_AODO = 0;   // Age of Data Offset (AODO) term for the navigation message correction table (NMCT) contained in subframe 4 (reference paragraph 20.3.3.5.1.9) [s]
 
-    b_fit_interval_flag = false; // indicates the curve-fit interval used by the CS (Block II/IIA/IIR/IIR-M/IIF) and SS (Block IIIA) in determining the ephemeris parameters, as follows: 0  =  4 hours, 1  =  greater than 4 hours.
-    d_spare1 = 0;
-    d_spare2 = 0;
+    b_fit_interval_flag = false;  // indicates the curve-fit interval used by the CS (Block II/IIA/IIR/IIR-M/IIF) and SS (Block IIIA) in determining the ephemeris parameters, as follows: 0  =  4 hours, 1  =  greater than 4 hours.
+    d_spare1 = 0.0;
+    d_spare2 = 0.0;
 
-    d_A_f0 = 0;          // Coefficient 0 of code phase offset model [s]
-    d_A_f1 = 0;          // Coefficient 1 of code phase offset model [s/s]
-    d_A_f2 = 0;          // Coefficient 2 of code phase offset model [s/s^2]
+    d_A_f0 = 0.0;  // Coefficient 0 of code phase offset model [s]
+    d_A_f1 = 0.0;  // Coefficient 1 of code phase offset model [s/s]
+    d_A_f2 = 0.0;  // Coefficient 2 of code phase offset model [s/s^2]
 
     b_integrity_status_flag = false;
     b_alert_flag = false;         // If true, indicates  that the SV URA may be worse than indicated in d_SV_accuracy, use that SV at our own risk.
     b_antispoofing_flag = false;  //  If true, the AntiSpoofing mode is ON in that SV
 
     auto gnss_sat = Gnss_Satellite();
-    std::string _system ("GPS");
-    for(unsigned int i = 1; i < 33; i++)
+    std::string _system("GPS");
+    for (uint32_t i = 1; i < 33; i++)
         {
             satelliteBlock[i] = gnss_sat.what_block(_system, i);
         }
@@ -100,7 +100,7 @@ Gps_Ephemeris::Gps_Ephemeris()
 double Gps_Ephemeris::check_t(double time)
 {
     double corrTime;
-    double half_week = 302400.0;     // seconds
+    double half_week = 302400.0;  // seconds
     corrTime = time;
     if (time > half_week)
         {
@@ -117,14 +117,21 @@ double Gps_Ephemeris::check_t(double time)
 // 20.3.3.3.3.1 User Algorithm for SV Clock Correction.
 double Gps_Ephemeris::sv_clock_drift(double transmitTime)
 {
+    //    double dt;
+    //    dt = check_t(transmitTime - d_Toc);
+    //
+    //    for (int32_t i = 0; i < 2; i++)
+    //        {
+    //            dt -= d_A_f0 + d_A_f1 * dt + d_A_f2 * (dt * dt);
+    //        }
+    //    d_satClkDrift = d_A_f0 + d_A_f1 * dt + d_A_f2 * (dt * dt);
+
+
     double dt;
     dt = check_t(transmitTime - d_Toc);
-
-    for (int i = 0; i < 2; i++)
-        {
-            dt -= d_A_f0 + d_A_f1 * dt + d_A_f2 * (dt * dt);
-        }
-    d_satClkDrift = d_A_f0 + d_A_f1 * dt + d_A_f2 * (dt * dt);
+    d_satClkDrift = d_A_f0 + d_A_f1 * dt + d_A_f2 * (dt * dt) + sv_clock_relativistic_term(transmitTime);
+    //Correct satellite group delay
+    d_satClkDrift -= d_TGD;
 
     return d_satClkDrift;
 }
@@ -156,17 +163,17 @@ double Gps_Ephemeris::sv_clock_relativistic_term(double transmitTime)
     M = d_M_0 + n * tk;
 
     // Reduce mean anomaly to between 0 and 2pi
-    M = fmod((M + 2.0 * GPS_PI), (2.0 * GPS_PI));
+    //M = fmod((M + 2.0 * GPS_PI), (2.0 * GPS_PI));
 
     // Initial guess of eccentric anomaly
     E = M;
 
     // --- Iteratively compute eccentric anomaly ----------------------------
-    for (int ii = 1; ii < 20; ii++)
+    for (int32_t ii = 1; ii < 20; ii++)
         {
-            E_old   = E;
-            E       = M + d_e_eccentricity * sin(E);
-            dE      = fmod(E - E_old, 2.0 * GPS_PI);
+            E_old = E;
+            E = M + d_e_eccentricity * sin(E);
+            dE = fmod(E - E_old, 2.0 * GPS_PI);
             if (fabs(dE) < 1e-12)
                 {
                     //Necessary precision is reached, exit from the loop
@@ -215,17 +222,17 @@ double Gps_Ephemeris::satellitePosition(double transmitTime)
     M = d_M_0 + n * tk;
 
     // Reduce mean anomaly to between 0 and 2pi
-    M = fmod((M + 2.0 * GPS_PI), (2.0 * GPS_PI));
+    //M = fmod((M + 2.0 * GPS_PI), (2.0 * GPS_PI));
 
     // Initial guess of eccentric anomaly
     E = M;
 
     // --- Iteratively compute eccentric anomaly ----------------------------
-    for (int ii = 1; ii < 20; ii++)
+    for (int32_t ii = 1; ii < 20; ii++)
         {
-            E_old   = E;
-            E       = M + d_e_eccentricity * sin(E);
-            dE      = fmod(E - E_old, 2.0 * GPS_PI);
+            E_old = E;
+            E = M + d_e_eccentricity * sin(E);
+            dE = fmod(E - E_old, 2.0 * GPS_PI);
             if (fabs(dE) < 1e-12)
                 {
                     //Necessary precision is reached, exit from the loop
@@ -242,22 +249,22 @@ double Gps_Ephemeris::satellitePosition(double transmitTime)
     phi = nu + d_OMEGA;
 
     // Reduce phi to between 0 and 2*pi rad
-    phi = fmod((phi), (2.0 * GPS_PI));
+    //phi = fmod((phi), (2.0 * GPS_PI));
 
     // Correct argument of latitude
-    u = phi + d_Cuc * cos(2.0 * phi) +  d_Cus * sin(2.0 * phi);
+    u = phi + d_Cuc * cos(2.0 * phi) + d_Cus * sin(2.0 * phi);
 
     // Correct radius
-    r = a * (1.0 - d_e_eccentricity*cos(E)) +  d_Crc * cos(2.0 * phi) +  d_Crs * sin(2.0 * phi);
+    r = a * (1.0 - d_e_eccentricity * cos(E)) + d_Crc * cos(2.0 * phi) + d_Crs * sin(2.0 * phi);
 
     // Correct inclination
     i = d_i_0 + d_IDOT * tk + d_Cic * cos(2.0 * phi) + d_Cis * sin(2.0 * phi);
 
     // Compute the angle between the ascending node and the Greenwich meridian
-    Omega = d_OMEGA0 + (d_OMEGA_DOT - OMEGA_EARTH_DOT)*tk - OMEGA_EARTH_DOT * d_Toe;
+    Omega = d_OMEGA0 + (d_OMEGA_DOT - OMEGA_EARTH_DOT) * tk - OMEGA_EARTH_DOT * d_Toe;
 
     // Reduce to between 0 and 2*pi rad
-    Omega = fmod((Omega + 2.0 * GPS_PI), (2.0 * GPS_PI));
+    //Omega = fmod((Omega + 2.0 * GPS_PI), (2.0 * GPS_PI));
 
     // --- Compute satellite coordinates in Earth-fixed coordinates
     d_satpos_X = cos(u) * r * cos(Omega) - sin(u) * r * cos(i) * sin(Omega);
@@ -266,7 +273,7 @@ double Gps_Ephemeris::satellitePosition(double transmitTime)
 
     // Satellite's velocity. Can be useful for Vector Tracking loops
     double Omega_dot = d_OMEGA_DOT - OMEGA_EARTH_DOT;
-    d_satvel_X = - Omega_dot * (cos(u) * r + sin(u) * r * cos(i)) + d_satpos_X * cos(Omega) - d_satpos_Y * cos(i) * sin(Omega);
+    d_satvel_X = -Omega_dot * (cos(u) * r + sin(u) * r * cos(i)) + d_satpos_X * cos(Omega) - d_satpos_Y * cos(i) * sin(Omega);
     d_satvel_Y = Omega_dot * (cos(u) * r * cos(Omega) - sin(u) * r * cos(i) * sin(Omega)) + d_satpos_X * sin(Omega) + d_satpos_Y * cos(i) * cos(Omega);
     d_satvel_Z = d_satpos_Y * sin(i);
 
