@@ -8,7 +8,7 @@
 *
 * -------------------------------------------------------------------------
 *
-* Copyright (C) 2010-2017 (see AUTHORS file for a list of contributors)
+* Copyright (C) 2010-2018 (see AUTHORS file for a list of contributors)
 *
 * GNSS-SDR is a software defined Global Navigation
 * Satellite Systems receiver
@@ -26,39 +26,45 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
+* along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------
 */
+
 #ifndef GNSS_SDR_VERSION
-#define GNSS_SDR_VERSION "0.0.9"
+#define GNSS_SDR_VERSION "0.0.10"
 #endif
 
 #ifndef GOOGLE_STRIP_LOG
 #define GOOGLE_STRIP_LOG 0
 #endif
 
-#include <ctime>
-#include <cstdlib>
-#include <memory>
+#include "concurrent_map.h"
+#include "concurrent_queue.h"
+#include "control_thread.h"
+#include "gnss_sdr_flags.h"
+#include "gps_acq_assist.h"
 #include <boost/exception/diagnostic_information.hpp>
-#include <boost/exception_ptr.hpp>
-#include <boost/filesystem.hpp>
+#include <boost/exception/exception.hpp>    // for exception
+#include <boost/filesystem/operations.hpp>  // for create_directories, exists
+#include <boost/filesystem/path.hpp>        // for path, operator<<
+#include <boost/system/error_code.hpp>      // for error_code
 #include <gflags/gflags.h>
 #include <glog/logging.h>
-#include "control_thread.h"
-#include "concurrent_queue.h"
-#include "concurrent_map.h"
+#include <chrono>
+#include <exception>
+#include <iostream>
+#include <memory>
+#include <string>
 
 #if CUDA_GPU_ACCEL
-    // For the CUDA runtime routines (prefixed with "cuda_")
-    #include <cuda_runtime.h>
+// For the CUDA runtime routines (prefixed with "cuda_")
+#include <cuda_runtime.h>
 #endif
 
 
 using google::LogMessage;
 
-DECLARE_string(log_dir);
 
 /*
 * Concurrent queues that communicates the Telemetry Decoder
@@ -72,13 +78,10 @@ concurrent_map<Gps_Acq_Assist> global_gps_acq_assist_map;
 int main(int argc, char** argv)
 {
     const std::string intro_help(
-            std::string("\nGNSS-SDR is an Open Source GNSS Software Defined Receiver\n")
-    +
-    "Copyright (C) 2010-2017 (see AUTHORS file for a list of contributors)\n"
-    +
-    "This program comes with ABSOLUTELY NO WARRANTY;\n"
-    +
-    "See COPYING file to see a copy of the General Public License\n \n");
+        std::string("\nGNSS-SDR is an Open Source GNSS Software Defined Receiver\n") +
+        "Copyright (C) 2010-2018 (see AUTHORS file for a list of contributors)\n" +
+        "This program comes with ABSOLUTELY NO WARRANTY;\n" +
+        "See COPYING file to see a copy of the General Public License\n \n");
 
     const std::string gnss_sdr_version(GNSS_SDR_VERSION);
     google::SetUsageMessage(intro_help);
@@ -86,23 +89,23 @@ int main(int argc, char** argv)
     google::ParseCommandLineFlags(&argc, &argv, true);
     std::cout << "Initializing GNSS-SDR v" << gnss_sdr_version << " ... Please wait." << std::endl;
 
-    #if CUDA_GPU_ACCEL
-        // Reset the device
-        // cudaDeviceReset causes the driver to clean up all state. While
-        // not mandatory in normal operation, it is good practice.  It is also
-        // needed to ensure correct operation when the application is being
-        // profiled. Calling cudaDeviceReset causes all profile data to be
-        // flushed before the application exits
-        cudaDeviceReset();
-        std::cout << "Reset CUDA device done " << std::endl;
-    #endif
+#if CUDA_GPU_ACCEL
+    // Reset the device
+    // cudaDeviceReset causes the driver to clean up all state. While
+    // not mandatory in normal operation, it is good practice.  It is also
+    // needed to ensure correct operation when the application is being
+    // profiled. Calling cudaDeviceReset causes all profile data to be
+    // flushed before the application exits
+    cudaDeviceReset();
+    std::cout << "Reset CUDA device done " << std::endl;
+#endif
 
-    if(GOOGLE_STRIP_LOG == 0)
+    if (GOOGLE_STRIP_LOG == 0)
         {
             google::InitGoogleLogging(argv[0]);
             if (FLAGS_log_dir.empty())
                 {
-                    std::cout << "Logging will be done at "
+                    std::cout << "Logging will be written at "
                               << boost::filesystem::temp_directory_path()
                               << std::endl
                               << "Use gnss-sdr --log_dir=/path/to/log to change that."
@@ -110,7 +113,7 @@ int main(int argc, char** argv)
                 }
             else
                 {
-                    const boost::filesystem::path p (FLAGS_log_dir);
+                    const boost::filesystem::path p(FLAGS_log_dir);
                     if (!boost::filesystem::exists(p))
                         {
                             std::cout << "The path "
@@ -118,49 +121,77 @@ int main(int argc, char** argv)
                                       << " does not exist, attempting to create it."
                                       << std::endl;
                             boost::system::error_code ec;
-                            boost::filesystem::create_directory(p, ec);
-                            if(ec != 0)
+                            if (!boost::filesystem::create_directory(p, ec))
                                 {
                                     std::cout << "Could not create the " << FLAGS_log_dir << " folder. GNSS-SDR program ended." << std::endl;
                                     google::ShutDownCommandLineFlags();
-                                    std::exit(0);
+                                    return 1;
                                 }
                         }
-                    std::cout << "Logging with be done at " << FLAGS_log_dir << std::endl;
+                    std::cout << "Logging will be written at " << FLAGS_log_dir << std::endl;
                 }
         }
 
     std::unique_ptr<ControlThread> control_thread(new ControlThread());
 
     // record startup time
-    struct timeval tv;
-    gettimeofday(&tv, NULL);
-    long long int begin = tv.tv_sec * 1000000 + tv.tv_usec;
+    std::chrono::time_point<std::chrono::system_clock> start, end;
+    start = std::chrono::system_clock::now();
 
+    int return_code;
     try
-    {
-            control_thread->run();
-    }
-    catch( boost::exception & e )
-    {
-            LOG(FATAL) << "Boost exception: " << boost::diagnostic_information(e);
-    }
-    catch(std::exception const&  ex)
-    {
-            LOG(FATAL) << "STD exception: " << ex.what();
-    }
-    catch(...)
-    {
-            LOG(INFO) << "Unexpected catch";
-    }
+        {
+            return_code = control_thread->run();
+        }
+    catch (const boost::exception& e)
+        {
+            if (GOOGLE_STRIP_LOG == 0)
+                {
+                    LOG(WARNING) << "Boost exception: " << boost::diagnostic_information(e);
+                }
+            else
+                {
+                    std::cerr << "Boost exception: " << boost::diagnostic_information(e) << std::endl;
+                }
+            google::ShutDownCommandLineFlags();
+            return 1;
+        }
+    catch (const std::exception& ex)
+        {
+            if (GOOGLE_STRIP_LOG == 0)
+                {
+                    LOG(WARNING) << "C++ Standard Library exception: " << ex.what();
+                }
+            else
+                {
+                    std::cerr << "C++ Standard Library exception: " << ex.what() << std::endl;
+                }
+            google::ShutDownCommandLineFlags();
+            return 1;
+        }
+    catch (...)
+        {
+            if (GOOGLE_STRIP_LOG == 0)
+                {
+                    LOG(WARNING) << "Unexpected catch. This should not happen.";
+                }
+            else
+                {
+                    std::cerr << "Unexpected catch. This should not happen." << std::endl;
+                }
+            google::ShutDownCommandLineFlags();
+            return 1;
+        }
+
     // report the elapsed time
-    gettimeofday(&tv, NULL);
-    long long int end = tv.tv_sec * 1000000 + tv.tv_usec;
-    std::cout << "Total GNSS-SDR run time "
-              << (static_cast<double>(end - begin)) / 1000000.0
+    end = std::chrono::system_clock::now();
+    std::chrono::duration<double> elapsed_seconds = end - start;
+
+    std::cout << "Total GNSS-SDR run time: "
+              << elapsed_seconds.count()
               << " [seconds]" << std::endl;
 
     google::ShutDownCommandLineFlags();
     std::cout << "GNSS-SDR program ended." << std::endl;
-    return 0;
+    return return_code;
 }
